<?php

namespace App\Exports;

use App\Models\Asset;
use App\Models\Department;
use App\Models\Entity;
use App\Models\Level1;
use App\Models\Level2;
use App\Models\Level3;
use App\Models\Level4;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithTitle;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Schema;

class AssetSheet implements FromCollection, WithTitle, WithHeadings
{
    protected $title;
    protected $assets;
    protected $fields; // Add fields property

    public function __construct($title, Collection $assets, $fields)
    {
        $this->title = $title;
        $this->assets = $assets;
        $this->fields = $fields; // Assign fields property
    }

    public function collection()
    {
        // Check if 'level1', 'level2', 'level3', and 'level4' fields are selected for export
        $selectedFields = explode(',', $this->fields);
        $level1Selected = in_array('level1', $selectedFields);
        $level2Selected = in_array('level2', $selectedFields);
        $level3Selected = in_array('level3', $selectedFields);
        $level4Selected = in_array('level4', $selectedFields);
        $entity_id = in_array('entity_id', $selectedFields);
        $departmentSelected = in_array('department_id', $selectedFields);

        // Append level1 name to each asset row only if 'level1' is selected
        $assetsData = $this->assets->map(function ($asset) use ($level1Selected, $level2Selected, $level3Selected, $level4Selected, $entity_id, $departmentSelected) {
            if ($entity_id) {
                // Fetch level1 name based on ID from the level1 table
                $entity = Entity::where('id', $entity_id)->first();
                if ($entity) {
                    $asset['entity_id'] = $entity->entity_name;
                }
            }
            if ($level1Selected) {
                // Fetch level1 name based on ID from the level1 table
                $level1Name = Level1::where('id', $asset->level1)->first();
                if ($level1Name) {
                    $asset['level1'] = $level1Name->name; // Replace 'level1' id with 'level1' name
                    $asset['level1_ar'] = $level1Name->name_ar; // Replace 'level1' id with 'level1' name
                    $asset['level1_code'] = $level1Name->code; // Replace 'level1' id with 'level1' name
                }
            }

            if ($level2Selected) {
                // Fetch level2 name based on ID from the level2 table
                $level2Name = Level2::where('id', $asset->level2)->first();
                if ($level2Name) {
                    $asset['level2'] = $level2Name->name; // Replace 'level2' id with 'level2' name
                    $asset['level2_ar'] = $level2Name->name_ar; // Replace 'level1' id with 'level1' name
                    $asset['level2_code'] = $level2Name->code; // Replace 'level1' id with 'level1' name
                }
            }

            if ($level3Selected) {
                // Fetch level3 name based on ID from the level3 table
                $level3Name = Level3::where('id', $asset->level3)->first();
                if ($level3Name) {
                    $asset['level3'] = $level3Name->name; // Replace 'level3' id with 'level3' name
                    $asset['level3_ar'] = $level3Name->name_ar; // Replace 'level3' id with 'level3' name
                    $asset['level3_code'] = $level3Name->code; // Replace 'level3' id with 'level3' name
                }
            }

            if ($level4Selected) {
                // Fetch level4 name based on ID from the level4 table
                $level4Name = Level4::where('id', $asset->level4)->first();
                if ($level4Name) {
                    $asset['level4'] = $level4Name->name; // Replace 'level4' id with 'level4' name
                    $asset['level4_ar'] = $level4Name->name_ar; // Replace 'level4' id with 'level4' name
                    $asset['level4_code'] = $level4Name->code; // Replace 'level4' id with 'level4' name
                }
            }


            if ($departmentSelected) {
                $departmentData = Department::where('id', $asset->department_id)->first();
                if ($departmentData) {
                    $asset['department_full_name'] = Department::getFullName($departmentData);
                }
            }

            return $asset;
        });

        return $assetsData;
    }


    public function title(): string
    {
        return $this->title;
    }

    public function headings(): array
    {
        $table = (new Asset)->getTable();
        $columns = Schema::getColumnListing($table);

        // Filter column headings based on selected fields
        $selectedHeadings = array_intersect($columns, explode(',', $this->fields));

        $selectedFields = explode(',', $this->fields);
        $level1Selected = in_array('level1', $selectedFields);
        $level2Selected = in_array('level2', $selectedFields);
        $level3Selected = in_array('level3', $selectedFields);
        $level4Selected = in_array('level4', $selectedFields);
        $departmentSelected = in_array('department_id', $selectedFields);

        if ($level1Selected && $this->assets->isNotEmpty() && $this->assets->first()->level1) {
            $selectedHeadings['level1_ar'] = 'level1_ar';
            $selectedHeadings['level1_code'] = 'level1_code';
        }
        if ($level2Selected && $this->assets->isNotEmpty() && $this->assets->first()->level2) {
            $selectedHeadings['level2_ar'] = 'level2_ar';
            $selectedHeadings['level2_code'] = 'level2_code';
        }
        if ($level3Selected && $this->assets->isNotEmpty() && $this->assets->first()->level3) {
            $selectedHeadings['level3_ar'] = 'level3_ar';
            $selectedHeadings['level3_code'] = 'level3_code';
        }
        if ($level4Selected && $this->assets->isNotEmpty() && $this->assets->first()->level4) {
            $selectedHeadings['level4_ar'] = 'level4_ar';
            $selectedHeadings['level4_code'] = 'level4_code';
        }

        if ($departmentSelected && $this->assets->isNotEmpty() && $this->assets->first()->department_id) {
            $selectedHeadings['department_full_name'] = 'department_full_name';
        }

        return $selectedHeadings;
    }
}
