<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Entity;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class AuthController extends Controller
{

    /**
     * @OA\Post(
     *     path="/login",
     *     summary="Login User",
     *     tags={"login user"},
     *     @OA\RequestBody(
     *         required=true,
     *         description="User login details",
     *         @OA\MediaType(
     *             mediaType="application/json",
     *             @OA\Schema(
     *                 @OA\Property(property="email", type="string", example="user@gmail.com"),
     *                 @OA\Property(property="password", type="string", example="secret123")
     *             )
     *         )
     *     ),
     *     @OA\Response(response=200, description="Successful operation"),
     *     @OA\Response(response=400, description="Invalid request"),
     * )
     */
    public function login(Request $req)
    {
        $validator = Validator::make($req->all(), [
            'username' => 'required|string',
            'password' => 'required|string|min:6',
        ]);
        if ($validator->fails()) {
            return response([
                'errors' => $validator->errors()->all(),
                'status' => 422
            ]);
        }

        if (Auth::attempt(['username' => $req->username, 'password' => $req->password])) {
            $user = Auth::user();

            $success = $user->createToken('userToken')->plainTextToken;

            $userData = [
                'id' => $user->id,
                'name' => $user->name,
                'username' => $user->username,
                'phone' => $user->phone,
                'email' => $user->email,
            ];

            return response()->json([
                'message' => 'User Login Successfully!',
                'user' => $userData,
                'token' => $success,
                'status' => 200
            ]);
        } else {
            return response()->json([
                'message' => 'Unauthorized',
                'status' => 403
            ]);
        }
    }
}
