<?php

namespace App\Http\Controllers;

use App\Http\Requests\AssetStoreRequest;
use App\Models\Asset;
use App\Models\City;
use App\Models\Country;
use App\Models\Entity;
use App\Models\Level1;
use App\Models\Level2;
use App\Models\Level3;
use App\Models\Level4;
use App\Models\Region;
use App\Models\User;
use App\Models\ValuationMethod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\AssetsExport;
use App\Imports\customImportAsset;
use App\Imports\customImportAssetLevel;
use App\Imports\customImportAssetMachinary;
use App\Imports\ImportAsset;
use App\Jobs\AssetAssignJob;
use App\Jobs\AssetCoOwnerJob;
use App\Jobs\AssetImageUpdateJob;
use App\Models\Department;
use App\Models\Role;
use App\Models\Status;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use ZipArchive;

class AssetController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-asset')) {
            abort(403);
        }

        $asset = new Asset;
        $table = $asset->getTable();
        $columns  = \Schema::getColumnListing($table);
        $descriptions = Asset::distinct()->pluck('asset_description');
        $countries = Country::all();
        $regions = Region::all();
        $cities = City::all();
        $level3s = Level3::all();
        $buildings = Asset::distinct()->pluck('building_number');
        $floors = Asset::distinct()->pluck('floor_number');
        $rooms = Asset::distinct()->pluck('room_office_number');
        $data_entry_users = User::role(User::DATA_ENTRY_ROLE)->get();
        $field_users = User::role(User::FIELD_USER_ROLE)->get();

        return view('admin.asset.index', compact('columns', 'descriptions', 'countries', 'regions', 'cities', 'level3s', 'buildings', 'floors', 'rooms', 'data_entry_users', 'field_users'));
    }

    public function edit(Asset $asset, $type)
    {
        if (!$this->authorize('edit-asset')) {
            abort(403);
        }
        $types = $type;
        $entities = Entity::all();
        $users = User::all();
        $countries = Country::all();
        $regions = Region::all();
        $cities = City::all();
        $level1s = Level1::all();
        $level2s = Level2::all();
        $level3s = Level3::all();
        $level4s = Level4::all();
        $valuationMethods = ValuationMethod::all();

        $buildings = Asset::distinct()->pluck('building_number');
        $floors = Asset::distinct()->pluck('floor_number');
        $rooms = Asset::distinct()->pluck('room_office_number');
        $descriptions = Asset::distinct()->pluck('asset_description');

        $level1 = $asset['level1'];
        $level2 = $asset['level2'];
        $level3 = $asset['level3'];
        $level4 = $asset['level4'];

        $statuses = Status::all();

        $departments = $this->getDepartmentsFromSession();


        return view('admin.asset.edit', compact('entities', 'users', 'countries', 'regions', 'cities', 'level1s', 'level2s', 'level3s', 'level4s', 'types', 'valuationMethods', 'asset', 'statuses', 'buildings', 'floors', 'rooms', 'descriptions', 'departments'));
    }


    public function update(AssetStoreRequest $req, Asset $asset)
    {
        if (!$this->authorize('edit-asset')) {
            abort(403);
        }
        $input = $req->all();

        $id = $input['id'];
        $asset = Asset::findOrFail($id);

        // Fetch country, region, and city names based on IDs
        $country = Country::findOrFail($input['country']);
        $region = Region::findOrFail($input['region']);
        $city = City::findOrFail($input['city']);


        if ($input['building_number'] ==  'other') {
            if (!$req->filled('new_building_number')) {
                toast('Please enter New Building Number', 'error');
                return redirect()->back()->withErrors(['new_building_number' => 'New Building Number is required.'])->withInput();
            }
            $building_number = $input['new_building_number'];
        } else {
            $building_number = $input['building_number'];
        }


        if (isset($input['admin_status'])) {
            if ($input['admin_status'] ==  'other') {
                if (!$req->filled('custom_status')) {
                    toast('Please enter custom status', 'error');
                    return redirect()->back()->withErrors(['custom_status' => 'New Status is required.'])->withInput();
                }

                $admin_status = Status::firstOrCreate([
                    'name' => $req->input('custom_status'),
                ]);
            } else {
                $admin_status = Status::where('name', $input['admin_status'])->first();
            }
        }


        if ($input['room_office_number'] ==  'other') {
            if (!$req->filled('room_office_number')) {
                toast('Please enter New Room Office Number', 'error');
                return redirect()->back()->withErrors(['room_office_number' => 'New Room Office Number is required.'])->withInput();
            }

            $room_office_number = $input['new_room_office_number'];
        } else {
            $room_office_number = $input['room_office_number'];;
        }

        if ($input['floor_number'] ==  'other') {
            if (!$req->filled('new_floor_number')) {
                toast('Please enter New Floor Number', 'error');
                return redirect()->back()->withErrors(['new_floor_number' => 'New Floor Number is required.'])->withInput();
            }
            $floor_number = $input['new_floor_number'];
        } else {
            $floor_number = $input['floor_number'];;
        }

        if ($input['asset_description'] ==  'other') {
            if (!$req->filled('new_descripiton')) {
                toast('Please enter New Asset Descripiton', 'error');
                return redirect()->back()->withErrors(['new_descripiton' => 'New Asset Descripiton is required.'])->withInput();
            }
            $description = $input['new_descripiton'];
        } else {
            $description = $input['asset_description'];;
        }


        // Check if new files are uploaded
        $paths = [];

        if ($req->hasFile('asset_images')) {
            foreach ($req->file('asset_images') as $file) {
                $path = $file->store('asset_images');
                $paths[] = $path;
            }
        }

        // Handle removal of unchecked documents
        if ($asset->attachments->isNotEmpty()) {
            $existingAttachments = $asset->attachments->pluck('id')->toArray();
            $attachmentsToDelete = array_diff($existingAttachments, $req->input('existing_attachments', []));

            if (!empty($attachmentsToDelete)) {
                // Specify the table name along with the column name
                $asset->attachments()->whereIn('attachments.id', $attachmentsToDelete)->delete();
            }
        }

        // Attach new documents to the asset
        if (!empty($paths)) {
            $attachmentsData = [];
            foreach ($paths as $path) {
                $attachmentsData[] = ['url' => $path];
            }

            $asset->attachments()->createMany($attachmentsData);

            $userDetailForMail = User::where('username', $asset->assign_by)->first();
            if ($userDetailForMail) {
                $mailData = [
                    'title' => 'Mail From Qiam',
                    'body' => Auth::user()->username . " Changed The Asset Images",
                    'email' => $userDetailForMail->email,
                    'id' => $req->id,
                ];
                AssetImageUpdateJob::dispatch($mailData);
            }
            $assetUpdate = Asset::where('id', $id)->update(['flag' => "Pending for data entry"]);
        }

        $asset->update([
            'asset_type' => $input['asset_type'] ?? null,
            'entity_id' => $input['entity'],
            'asset_description' => $description,
            'accounting_group_arabic_description' => $input['accounting_group_arabic_description'],
            'accounting_group_english_description' => $input['accounting_group_english_description'],
            'accounting_group_code' => $input['accounting_group_code'],
            'remaining_useful_life' => $input['remaining_useful_life'],
            'useful_life' => $input['useful_life'],
            'asset_owner' => $input['asset_owner'],
            'country' => $country->name,
            'region' => $region->name,
            'city' => $city->name,
            'building_number' => $building_number,
            'floor_number' => $floor_number,
            'room_office_number' => $room_office_number,
            'acquisition_method' => $input['acquisition_method'] ?? null,
            'date_placed_in_service' => $input['date_placed_in_service'] ?? null,
            'acquisition_date' => $input['acquisition_date'] ?? null,
            'acquisition_cost' => $input['acquisition_cost'] ?? null,
            'archive_document_number' => $input['archive_document_number'] ?? null,
            'asset_condition' => $input['asset_condition'] ?? null,
            'tag_number' => $input['tags'] ?? null,
            'inspection_date' => $input['inspection_date'] ?? null,
            'valuation_method' => $input['valuation_method'] ?? null,
            'valuation_report_date' => $input['valuation_report_date'] ?? null,
            'opening_balance_date' => $input['opening_balance_date'],
            'asset_opening_value' => $input['asset_opening_value'],
            'valuation_report_reference' => $input['valuation_report_reference'] ?? null,
            'base_unit_of_measure' => $input['base_unit_of_measure'],
            'level1' => $input['level1'] ?? null,
            'level2' => $input['level2'] ?? null,
            'level3' => $input['level3'] ?? null,
            'level4' => $input['level4'] ?? null,
            'unique_factory_id' => $input['unique_factory_id'] ?? null,
            'geographical_coordinates' => $input['geographical_coordinates'] ?? null,
            'manufacturer' => $input['manufacturer'] ?? null,
            'model' => $input['model'] ?? null,
            'quantity' => $input['quantity'],
            'longitute' => $input['longitute'],
            'latitude' => $input['latitude'],
            'admin_status' => $admin_status->name ?? null,
            'user_status' => $input['user_status'] ?? null,
            'serial_number' => $input['serial_number'] ?? null,
            'asset_have_serial_number' => $input['asset_have_serial_number'] ?? null,
            'supportive_document_for_acquisition_cost' => $input['supportive_document_for_acquisition_cost'] ?? null,
            'employee_custody' => $input['employee_custody'] ?? null,
            'department_id' => $input['department'] ?? null,
        ]);

        toast('Asset updated', 'success');
        return redirect()->route('assets');
    }


    public function show(Asset $asset)
    {
        if (!$this->authorize('view-asset')) {
            abort(403);
        }
        $level1Name = Level1::where('id', $asset->level1)->first();
        $level2Name = Level2::where('id', $asset->level2)->first();
        $level3Name = Level3::where('id', $asset->level3)->first();
        $level4Name = Level4::where('id', $asset->level4)->first();

        return view('admin.asset.show', compact('asset', 'level1Name', 'level2Name', 'level3Name', 'level4Name'));
    }


    public function delete(Asset $asset)
    {
        if (!$this->authorize('delete-asset')) {
            abort(403);
        }
        $asset->delete();
        $asset->attachments()->delete();
        toast('Asset Deleted!', 'success');
        return redirect()->back();
    }

    public function deleteAll(Request $req)
    {
        if (!$this->authorize('delete-asset')) {
            abort(403);
        }
        $ids = $req->input('id');

        // Ensure that $ids is not empty before proceeding
        if (!empty($ids)) {
            // Retrieve assets based on the array of IDs
            $assets = Asset::whereIn('id', $ids)->get();

            // Delete attachments associated with each asset
            foreach ($assets as $asset) {
                $asset->attachments()->delete();
            }

            // Delete records based on the array of IDs
            Asset::whereIn('id', $ids)->delete();

            toast('Multiple Assets and Associated Documents Deleted!', 'success');
        }

        return redirect()->back();
    }

    public function editAll(Request $request)
    {
        if (!$this->authorize('edit-asset')) {
            abort(403);
        }
        $ids = $request->query('ids');
        $idsArray = is_string($ids) ? explode(',', $ids) : [];
        $asset = Asset::all();
        // dd($asset);
        $level1s = Level1::all();
        $level2s = Level2::all();
        $level3s = Level3::all();
        $level4s = Level4::all();
        $countries = Country::all();
        $regions = Region::all();
        $cities = City::all();

        return view('admin.asset.editAll', compact('idsArray', 'ids', 'asset', 'level1s', 'level2s', 'level3s', 'level4s', 'countries', 'regions', 'cities'));
    }

    public function bulkUpdate(Request $req)
    {
        if (!$this->authorize('edit-asset')) {
            abort(403);
        }
        $ids = $req->input('id');
        $idsArray = is_string($ids) ? explode(',', $ids) : [];


        if ($req->country) {
            $country = Country::findOrFail($req->country);
        }

        if ($req->region) {
            $region = Region::findOrFail($req->region);
        }

        if ($req->city) {
            $city = City::findOrFail($req->city);
        }

        // Build the update array based on user input
        $updateData = [];
        $fillableFields = ['level1', 'level2', 'level3', 'level4', 'building_number', 'floor_number', 'room_office_number', 'longitute', 'latitude', 'acquisition_method', 'acquisition_date', 'acquisition_cost', 'unique_factory_id', 'geographical_coordinates', 'manufacturer', 'model', 'asset_condition', 'country', 'region', 'city', 'employee_custody'];

        foreach ($fillableFields as $field) {
            if ($req->filled($field)) {
                // If the field is one of the related fields (e.g., country, region, city)
                // Fetch the name based on the ID and store it in the update array
                if (in_array($field, ['country', 'region', 'city'])) {
                    $name = $field === 'country' ? $country->name : ($field === 'region' ? $region->name : $city->name);
                    $updateData[$field] = $name;
                } else {
                    // For other fields, use the input directly
                    $updateData[$field] = $req->input($field);
                }
            }
        }

        // Update records based on the array of IDs
        Asset::whereIn('id', $idsArray)->update($updateData);

        toast('Bulk Asset Updated Successfully!', 'success');
        return redirect()->route('assets');
    }

    public function create(Entity $entity, $type)
    {
        if (!$this->authorize('create-asset')) {
            abort(403);
        }
        $entities = $entity->all();
        $users = User::all();
        $countries = Country::all();
        $regions = Region::all();
        $cities = City::all();
        $level1 = Level1::all();
        $level2 = Level2::all();
        $level3 = Level3::all();
        $level4 = Level4::all();
        $valuationMethod = ValuationMethod::all();
        $statuses = Status::all();
        $buildings = Asset::distinct()->pluck('building_number');
        $floors = Asset::distinct()->pluck('floor_number');
        $rooms = Asset::distinct()->pluck('room_office_number');
        $descriptions = Asset::distinct()->pluck('asset_description');
        $date = Carbon::now()->format('Y-m-d');

        $departments = $this->getDepartmentsFromSession();

        return view('admin.asset.form', ['entities' => $entities, 'users' => $users, 'countries' => $countries, 'regions' => $regions, 'cities' => $cities, 'level1s' => $level1, 'level2s' => $level2, 'level3s' => $level3, 'level4s' => $level4, 'type' => $type, 'valuationMethods' => $valuationMethod, 'statuses' => $statuses, 'buildings' => $buildings, 'floors' => $floors, 'rooms' => $rooms, 'descriptions' => $descriptions, 'date' => $date, 'departments' => $departments]);
    }

    protected function getDepartmentsFromSession()
    {
        // Check if departments are not in session or the session has expired
        if (!session()->has('departments') || Carbon::now()->greaterThan(session('departments_expiry'))) {
            // Forget the old session data
            session()->forget('departments');
            session()->forget('departments_expiry');

            // Fetch new departments from the database
            $all_departments = Department::all();

            // Build full names for all departments
            $this->buildFullNames($all_departments);

            $departments = [];
            foreach ($all_departments as $department) {
                $departments[] = [
                    'full_name' => $department->full_name,
                    'id' => $department->id
                ];
            }

            // Store new departments and their expiry time in the session
            session([
                'departments' => $departments,
                'departments_expiry' => Carbon::now()->addDay(),
            ]);
        } else {
            // Retrieve departments from the session
            $departments = session('departments');
        }

        return $departments;
    }

    private function buildFullNames(&$departments, $parent = null, $full_name = '')
    {
        foreach ($departments as $department) {
            if ($department->departments_id == $parent) {
                $current_full_name = $full_name ? $full_name . ' / ' . $department->name : $department->name;
                $department->full_name = $current_full_name;
                $this->buildFullNames($departments, $department->id, $current_full_name);
            }
        }
    }

    public function store(Request $req)
    {
        if (!$this->authorize('create-asset')) {
            abort(403);
        }

        $input = $req->all();
        if ($input['building_number'] ==  'other') {
            if (!$req->filled('new_building_number')) {
                toast('Please enter New Building Number', 'error');
                return redirect()->back()->withErrors(['new_building_number' => 'New Building Number is required.'])->withInput();
            }
            $building_number = $input['new_building_number'];
        } else {
            $building_number = $input['building_number'];
        }

        if (isset($input['admin_status'])) {
            if ($input['admin_status'] ==  'other') {
                if (!$req->filled('custom_status')) {
                    toast('Please enter custom status', 'error');
                    return redirect()->back()->withErrors(['custom_status' => 'New Status is required.'])->withInput();
                }

                $admin_status = Status::firstOrCreate([
                    'name' => $req->input('custom_status'),
                ]);
            } else {
                $admin_status = Status::where('name', $input['admin_status'])->first();
            }
        }

        if ($input['room_office_number'] ==  'other') {
            if (!$req->filled('new_room_office_number')) {
                toast('Please enter New Room Office Number', 'error');
                return redirect()->back()->withErrors(['new_room_office_number' => 'New Room Office Number is required.'])->withInput();
            }
            $room_office_number = $input['new_room_office_number'];
        } else {
            $room_office_number = $input['room_office_number'];;
        }

        if ($input['floor_number'] ==  'other') {
            if (!$req->filled('new_floor_number')) {
                toast('Please enter New Floor Number', 'error');
                return redirect()->back()->withErrors(['new_floor_number' => 'New Floor Number is required.'])->withInput();
            }
            $floor_number = $input['new_floor_number'];
        } else {
            $floor_number = $input['floor_number'];;
        }

        if ($input['asset_description'] ==  'other') {
            if (!$req->filled('new_descripiton')) {
                toast('Please enter New Asset Descripiton', 'error');
                return redirect()->back()->withErrors(['new_descripiton' => 'New Asset Descripiton is required.'])->withInput();
            }
            $description = $input['new_descripiton'];
        } else {
            $description = $input['asset_description'];;
        }

        $tags = explode(',', $req->input('tags'));

        $tagsWithErrors = [];

        foreach ($tags as $tag) {
            $validator = Validator::make(['asset_tag' => $tag], [
                'asset_tag' => 'required|unique:assets,tag_number',
            ]);

            if ($validator->fails()) {
                $tagsWithErrors[] = $validator->errors()->first() . '( ' . $tag . ' )';
            }
        }
        if (!empty($tagsWithErrors)) {
            toast($tagsWithErrors, 'error');
            return redirect()->back();
        }


        // Fetch country, region, and city names based on IDs
        $country = Country::findOrFail($input['country']);
        $region = Region::findOrFail($input['region']);
        $city = City::findOrFail($input['city']);

        // Check if new files are uploaded
        $paths = [];

        if ($req->hasFile('asset_images')) {
            foreach ($req->file('asset_images') as $file) {
                $path = $file->store('asset_images');
                $paths[] = $path;
            }
        }

        foreach ($tags as $tag) {
            $asset = Asset::create([
                'asset_type' => $input['asset_type'],
                'entity_id' => $input['entity'],
                'asset_description' => $description,
                'accounting_group_arabic_description' => $input['accounting_group_arabic_description'],
                'accounting_group_english_description' => $input['accounting_group_english_description'],
                'accounting_group_code' => $input['accounting_group_code'],
                'remaining_useful_life' => $input['remaining_useful_life'],
                'useful_life' => $input['useful_life'],
                'asset_owner' => $input['asset_owner'],
                // 'assign_by' => Auth::user()->username,
                'country' => $country->name,
                'region' => $region->name,
                'city' => $city->name,
                'building_number' => $building_number,
                'floor_number' => $floor_number,
                'room_office_number' => $room_office_number,
                'acquisition_method' => $input['acquisition_method'] ?? null,
                'date_placed_in_service' => $input['date_placed_in_service'] ?? null,
                'acquisition_date' => $input['acquisition_date'] ?? null,
                'acquisition_cost' => $input['acquisition_cost'] ?? null,
                'archive_document_number' => $input['archive_document_number'] ?? null,
                'asset_condition' => $input['asset_condition'] ?? null,
                'tag_number' => $tag,
                'inspection_date' => Carbon::now()->format('Y-m-d'),
                'valuation_method' => $input['valuation_method'] ?? null,
                'valuation_report_date' => $input['valuation_report_date'] ?? null,
                'opening_balance_date' => $input['opening_balance_date'],
                'asset_opening_value' => $input['asset_opening_value'],
                'valuation_report_reference' => $input['valuation_report_reference'] ?? null,
                'base_unit_of_measure' => $input['base_unit_of_measure'],
                'level1' => $input['level1'] ?? null,
                'level2' => $input['level2'] ?? null,
                'level3' => $input['level3'] ?? null,
                'level4' => $input['level4'] ?? null,
                'unique_factory_id' => $input['unique_factory_id'] ?? null,
                'geographical_coordinates' => $input['geographical_coordinates'] ?? null,
                'manufacturer' => $input['manufacturer'] ?? null,
                'model' => $input['model'] ?? null,
                'quantity' => $input['quantity'],
                'longitute' => $input['longitute'],
                'latitude' => $input['latitude'],
                'admin_status' => $admin_status->name ?? null,
                'serial_number' => $input['serial_number'] ?? null,
                'asset_have_serial_number' => $input['asset_have_serial_number'] ?? null,
                'supportive_document_for_acquisition_cost' => $input['supportive_document_for_acquisition_cost'] ?? null,
                'employee_custody' => $input['employee_custody'] ?? null,
                'department_id' => $input['department'] ?? null,
            ]);

            // Associate attachments with the asset
            $asset->attachments()->createMany(
                collect($paths)->map(function ($path) {
                    return ['url' => $path];
                })->all()
            );
        }

        if (isset($input['asset_co_owner'])) {
            $userDetail = User::where('username', $input['asset_co_owner'])->first();

            if ($userDetail && !$userDetail->hasRole(User::USER_ROLE)) {
                $userRole = Role::where('name', User::USER_ROLE)->first();
                $userDetail->assignRole($userRole);
            }

            $mailData = [
                'title' => 'Congratulations you are the Co-Owner of new asset',
                'body' => "Hello $req->asset_co_owner! Congratulations you are the Co-Owner of new asset.",
                'email' => $userDetail->email,
            ];

            AssetCoOwnerJob::dispatch($mailData);
        }

        toast('Asset Created Successfully!', 'success');
        return redirect()->route('assets');
    }

    public function fetchRegions($countryId)
    {
        $regions = Region::where('country_id', $countryId)->get();

        return response()->json($regions);
    }

    public function fetchCities($regionId)
    {
        $cities = City::where('region_id', $regionId)->get();

        return response()->json($cities);
    }

    public function assetsDocsDownload(Request $req)
    {
        $files = $req->filename;

        return Storage::download($files);
    }

    public function selectToExport(Request $req)
    {
        $id = $req->query('asset');

        $asset = new Asset;
        $table = $asset->getTable();
        $columns  = \Schema::getColumnListing($table);

        return view('admin.asset.selectToExport', compact('id', 'columns'));
    }


    public function export(Request $req)
    {
        if (!$this->authorize('export-asset')) {
            abort(403);
        }

        $ids = session('asset_ids');

        if (empty($ids)) {
            toast('No asset found in session for export.Please Try Again', 'warning');
            return redirect()->route('assets');
        }

        $idsArray = is_string($ids) ? explode(',', $ids) : [];
        $fields = $req->fields;

        if (empty($fields)) {
            toast('No asset fields selected.Please Select at least one field', 'warning');
            return redirect()->back();
        }
        $fieldsString = implode(',', $fields);

        // Retrieve assets based on provided IDs
        $assetsQuery = Asset::whereIn('id', $idsArray);
        // Select only the specified fields
        $assetsData = $assetsQuery->get(explode(',', $fieldsString));

        // Group assets by entity name (category)
        $groupedAssets = $assetsData->groupBy('asset_type');

        // Create an export instance with filtered assets data and selected fields
        $export = new AssetsExport(collect($groupedAssets), $fieldsString);

        // Export to Excel with multiple sheets
        $response = Excel::download($export, 'assets.xlsx');

        session()->forget('asset_ids');

        return $response;
    }

    public function bulkExport(Request $req)
    {
        if (!$this->authorize('export-asset')) {
            abort(403);
        }

        $ids = $req->query('ids');
        $idsArray = is_string($ids) ? explode(',', $ids) : [];

        $fields = $req->query('fields'); // Assuming this is already an array

        if (empty($fields)) {
            toast('No asset fields selected.Please Select at least one field', 'warning');
            return redirect()->back();
        }

        // Retrieve assets based on provided IDs
        $assetsQuery = Asset::whereIn('id', $idsArray);

        // Select only the specified fields
        $assetsData = $assetsQuery->get(explode(',', $fields));

        // Group assets by entity name (category)
        $groupedAssets = $assetsData->groupBy('asset_type');
        // Create an export instance with filtered assets data and selected fields
        $export = new AssetsExport(collect($groupedAssets), $fields);

        // Export to Excel with multiple sheets
        return Excel::download($export, 'assets.xlsx');
    }


    public function importAssets(Request $req)
    {
        if (!$this->authorize('import-asset')) {
            abort(403);
        }

        if ($req->hasFile('file')) {
            Excel::import(new ImportAsset, $req->file('file')->store('import_asset'));
            return redirect()->back();
        } else {
            toast('Please select a file', 'warning');
            return redirect()->back();
        }
    }

    public function assign(Request $req)
    {
        if (!$this->authorize('assign-asset')) {
            abort(403);
        }

        $users = User::whereHas('roles', function ($query) {
            $query->where('name', User::DATA_ENTRY_ROLE);
        })->get();

        $asset = Asset::find($req->asset);
        return view('admin.asset.assignAsset', compact('users', 'asset'));
    }

    public function assignSingleTask(Request $req)
    {
        if (!$this->authorize('assign-asset')) {
            abort(403);
        }

        if ($req->asset_assign == "unSelect") {
            $user = null;
        } else {
            $user = $req->asset_assign;
        }

        $asset = Asset::find($req->id);
        $asset->asset_assign = $user;
        $asset->assign_by = Auth::user()->username;
        $asset->save();

        toast('Action Applied Successfully!', 'success');
        return redirect()->route('assets');
    }

    public function tasks()
    {
        if (!$this->authorize('assign-asset')) {
            abort(403);
        }

        $furniture = Asset::whereNull('asset_assign')->where('asset_type', 'furniture')->count();
        $machinary = Asset::whereNull('asset_assign')->where('asset_type', 'plantAndMachinery')->count();
        $users = User::all();
        $countries = Country::all();
        return view('admin.asset.task', compact('users', 'countries', 'furniture', 'machinary'));
    }

    // AssignAsset
    public function assignTasks(Request $req)
    {
        if (!$this->authorize('assign-asset')) {
            abort(403);
        }

        $totalAssets = Asset::whereNull('asset_assign')->count();

        // Get the number of tasks from the request
        $numberOfTasks = $req->number_of_tasks;

        // Check if the number of tasks exceeds the total number of assets
        if ($numberOfTasks > $totalAssets) {
            toast('Number of tasks cannot be greater than total number of assets!', 'error');
            return redirect()->back();
        }

        $country = Country::findOrFail($req->country);
        $region = Region::findOrFail($req->region);

        $assets = Asset::where('asset_type', $req->asset_type)->where('country', $country->name)->where('region', $region->name)->whereNull('asset_assign')->get();


        $user = User::where('username', $req->asset_assign)->first();
        // dd($user);
        if (!$assets->isEmpty()) {
            $assignedAssets = $assets->take($numberOfTasks);

            foreach ($assignedAssets as $asset) {
                $asset->asset_assign = $req->asset_assign;
                $asset->save();
            }

            $mailData = [
                'title' => 'Mail From Qiam',
                'body' => "New Asset Assigned!",
                'email' => $user->email,
            ];

            AssetAssignJob::dispatch($mailData);

            toast('Asset Assign Successfully!', 'success');
            return redirect()->back();
        } else {
            toast('Asset not found on the selected filter!', 'error');
            return redirect()->back();
        }
    }

    public function checkLocation(Request $req)
    {
        $country = Country::findOrFail($req->country);
        $region = Region::findOrFail($req->region);

        $user = User::where('username', $req->asset_assign)->first();

        if ($user->country == $country->name && $user->region == $region->name) {
            // If location matches, return success response
            return response()->json(['success' => true]);
        } else {
            // If location does not match, return failure response
            return response()->json(['success' => false]);
        }
    }

    public function customImport()
    {
        return view('admin.asset.customImport');
    }

    public function customImportAssetFurniture(Request $req)
    {
        if ($req->hasFile('file')) {
            Excel::import(new customImportAsset, $req->file('file')->store('custom_import_asset'));
            return redirect()->back();
        } else {
            toast('Please select a file', 'warning');
            return redirect()->back();
        }
    }

    public function customImportAssetMachinery(Request $req)
    {
        if ($req->hasFile('file')) {
            Excel::import(new customImportAssetMachinary, $req->file('file')->store('custom_import_asset'));
            return redirect()->back();
        } else {
            toast('Please select a file', 'warning');
            return redirect()->back();
        }
    }

    public function customImportLevel()
    {
        return view('admin.asset.customImportLevel');
    }

    public function customImportAssetLevel(Request $req)
    {
        if ($req->hasFile('file')) {
            Excel::import(new customImportAssetLevel, $req->file('file')->store('custom_import_asset'));
            return redirect()->back();
        } else {
            toast('Please select a file', 'warning');
            return redirect()->back();
        }
    }

    public function getAssets(Request $req)
    {
        $draw = $req->get('draw'); // Internal use
        $start = $req->get("start"); // where to start next records for pagination
        $rowPerPage = $req->get("length"); // How many records needed per page for pagination

        $assets = Asset::query();

        if (Auth::user()->hasRole(User::SUPER_ADMIN_ROLE)) {
            $assets->orderBy('created_at', 'desc');
        } elseif (Auth::user()->hasRole(User::SUPERVISOR_ROLE) && Auth::user()->hasRole(User::DATA_ENTRY_ROLE)) {
            $assets->where(function ($query) {
                $query->where('region', Auth::user()->region)
                    ->orWhere('asset_assign', Auth::user()->username);
            })->orderBy('created_at', 'desc');
        } elseif (Auth::user()->hasRole(User::SUPERVISOR_ROLE)) {
            $assets->Where('region', Auth::user()->region)->orderBy('created_at', 'desc');
        } elseif (Auth::user()->hasRole(User::DATA_ENTRY_ROLE)) {
            $assets->where('asset_assign', Auth::user()->username)->orderBy('created_at', 'desc');
        } elseif (Auth::user()->hasRole(User::FIELD_USER_ROLE)) {
            $assets->where('asset_owner', Auth::user()->username)->orderBy('created_at', 'desc');
        }

        // Filter by asset type if provided
        if ($req->has('asset_type')) {
            $assets->where('asset_type', 'like', '%' . $req->asset_type . '%');
        }
        if ($req->has('description')) {
            $assets->where('asset_description', 'like', '%' . $req->description . '%');
        }
        if ($req->has('country')) {
            $assets->where('country', 'like', '%' . $req->country . '%');
        }
        if ($req->has('region')) {
            $assets->where('region', 'like', '%' . $req->region . '%');
        }
        if ($req->has('city')) {
            $assets->where('city', 'like', '%' . $req->city . '%');
        }
        if ($req->has('barcode_number')) {
            $assets->where('tag_number', 'like', '%' . $req->barcode_number . '%');
        }
        if ($req->has('building_number')) {
            $assets->where('building_number', 'like', '%' . $req->building_number . '%');
        }
        if ($req->has('floor_number')) {
            $assets->where('floor_number', 'like', '%' . $req->floor_number . '%');
        }
        if ($req->has('room_office_number')) {
            $assets->where('room_office_number', 'like', '%' . $req->room_office_number . '%');
        }
        if ($req->has('level_3')) {
            if ($req->level_3) {
                $data = Level3::where('name', $req->level_3)->first();
                if ($data) {
                    $assets->where('level3', $data->id);
                }
            }
        }
        if ($req->has('multi_tags')) {
            if ($req->multi_tags) {

                $tags = explode(',', $req->multi_tags);

                $assets->whereIn('tag_number', $tags);
            }
        }
        if ($req->has('asset_assign')) {
            if ($req->asset_assign) {
                $assets->where('asset_assign', $req->asset_assign);
            }
        }
        if ($req->has('asset_owner')) {
            if ($req->asset_owner) {
                $assets->where('asset_owner', $req->asset_owner);
            }
        }

        // Execute the query
        $total = $assets->count();
        $totalFilter = $total;

        $arrData = $assets->skip($start)->take($rowPerPage)->get();


        // Modify the data structure to include HTML for the checkbox column
        $data = [];

        foreach ($arrData as $asset) {
            $l3 = Level3::where('id', $asset->level3)->value('name_ar');
            $assetType = $asset->asset_type === 'plantAndMachinery' ? 'Plant & Machinery' : $asset->asset_type;

            $buttons = view('admin.partials.action', [
                'edit_route' => route('edit.asset', ['asset' => $asset['id'], 'type' => $asset['asset_type']]),
                'view_route' => route('show.asset', ['asset' => $asset['id']]),
                'export_route' => route('single_export.asset', ['asset' => $asset['id']]),
                'delete_route' => route('delete.asset', ['asset' => $asset['id']]),
                'assign_route' => route('assign.asset', ['asset' => $asset['id']]),
                'image_download_route' => route('download.image', ['asset' => $asset['id']]),
                'edit_permission' => 'edit-asset',
                'delete_permission' => 'delete-asset',
                'view_permission' => 'view-asset',
                'export_permission' => 'export-asset',
                'assign_permission' => 'assign-asset',
                'image_download_permission' => 'download-asset-images',
            ])->render();

            $data[] = [
                'checkbox' => '<input type="checkbox" class="sub_checkboxes" name="sub_checkboxes[]" value="' . $asset->id . '">',
                'id' => $asset->id,
                'asset_type' => $assetType,
                'tag_number' => $asset->tag_number,
                'level3' => $l3,
                'country' => $asset->country,
                'region' => $asset->region,
                'city' => $asset->city,
                'user_status' => $asset->user_status,
                'admin_status' => $asset->admin_status,
                'building_number' => $asset->building_number,
                'floor_number' => $asset->floor_number,
                'room_office_number' => $asset->room_office_number,
                'asset_assign' => $asset->asset_assign,
                'asset_description' => $asset->asset_description,
                'image' => $asset->attachments->first()
                    ? asset('storage/' . $asset->attachments->first()->url)
                    : asset('admin/img/add-photo2.png'),
                'allImage' => $asset->attachments
                    ? $asset->attachments->pluck('url')->toArray()
                    : asset('admin/img/add-photo2.png'),
                'action' => $buttons,
            ];
        }

        $response = array(
            "draw" => intval($draw),
            "recordsTotal" => $total,
            "recordsFiltered" => $totalFilter,
            "data" => $data,
        );

        return response()->json($response);
    }

    public function countryWiseAssets(Request $req)
    {
        $country = Country::find($req->country_id);
        $furnitureAssets = Asset::where('country', $country->name)->whereNull('asset_assign')->where('asset_type', 'furniture')->count();
        $machinaryAssets = Asset::where('country', $country->name)->whereNull('asset_assign')->where('asset_type', 'plantAndMachinery')->count();

        return response()->json([
            'furniture' => $furnitureAssets,
            'machinary' => $machinaryAssets
        ]);
    }

    public function regionWiseAssets(Request $req)
    {
        $region = Region::find($req->region_id);
        $furnitureAssets = Asset::where('region', $region->name)->whereNull('asset_assign')->where('asset_type', 'furniture')->count();
        $machinaryAssets = Asset::where('region', $region->name)->whereNull('asset_assign')->where('asset_type', 'plantAndMachinery')->count();

        return response()->json([
            'furniture' => $furnitureAssets,
            'machinary' => $machinaryAssets
        ]);
    }

    public function singleExport(Request $req)
    {
        if (!$this->authorize('export-asset')) {
            abort(403);
        }
        $id = $req->query('asset');

        session()->forget('asset_ids');
        session(['asset_ids' => $id]);

        return redirect()->route('export.asset');
    }

    public function downloadImage(Request $req)
    {
        if (!$this->authorize('download-asset-images')) {
            abort(403);
        }

        $id = $req->query('asset');
        $asset = Asset::find($id);

        if (!$asset) {
            toast('No Asset Found', 'warning');
            return redirect()->back();
        }

        $images = $asset->attachments;

        if ($images->isEmpty()) {
            toast('No Image Found', 'warning');
            return redirect()->back();
        }

        // Create a temporary file for the ZIP archive
        $zipFileName = $asset->tag_number . '.zip';
        $zipFilePath = storage_path('app/public/' . $zipFileName);

        $zip = new ZipArchive;
        if ($zip->open($zipFilePath, ZipArchive::CREATE) === TRUE) {
            foreach ($images as $img) {
                // Get the file content from storage
                $fileContent = Storage::get($img->url);

                // Add the file to the ZIP archive
                $zip->addFromString(basename($img->url), $fileContent);
            }
            $zip->close();

            // Serve the ZIP file for download
            return response()->download($zipFilePath)->deleteFileAfterSend(true);
        } else {
            toast('Failed to create ZIP file', 'error');
            return redirect()->back();
        }
    }

    public function downloadAllImage()
    {
        if (!$this->authorize('download-asset-images')) {
            abort(403);
        }

        $assets = Asset::all();

        if ($assets->isEmpty()) {
            toast('No Asset Found', 'warning');
            return redirect()->back();
        }

        // Create a temporary file for the main ZIP archive
        $mainZipFileName = 'all_assets_images.zip';
        $mainZipFilePath = storage_path('app/public/' . $mainZipFileName);
        $mainZip = new ZipArchive;

        if ($mainZip->open($mainZipFilePath, ZipArchive::CREATE) === TRUE) {
            foreach ($assets as $asset) {
                $images = $asset->attachments;

                if (!$images->isEmpty()) {
                    // Create a temporary file for the individual asset ZIP archive
                    $assetZipFileName = $asset->tag_number . '.zip';
                    $assetZipFilePath = storage_path('app/public/' . $assetZipFileName);
                    $assetZip = new ZipArchive;

                    if ($assetZip->open($assetZipFilePath, ZipArchive::CREATE) === TRUE) {
                        foreach ($images as $img) {
                            // Get the file content from storage
                            $fileContent = Storage::get($img->url);

                            // Add the file to the asset ZIP archive
                            $assetZip->addFromString(basename($img->url), $fileContent);
                        }
                        $assetZip->close();

                        // Add the individual asset ZIP archive to the main ZIP archive
                        $mainZip->addFile($assetZipFilePath, $asset->tag_number . '.zip');
                    }
                }
            }
            $mainZip->close();

            // Serve the main ZIP file for download
            return response()->download($mainZipFilePath)->deleteFileAfterSend(true);
        } else {
            toast('Failed to create ZIP file', 'error');
            return redirect()->back();
        }
    }
}
