<?php

namespace App\Http\Controllers;

use App\Http\Requests\CityStoreRequest;
use App\Models\City;
use App\Models\Region;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class CityController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-city')) {
            abort(403);
        }
        if ($req->ajax()) {

            $cities = City::all();
            $table_data = [];

            foreach ($cities as $city) {
                $table_data[] = [
                    'id' => $city->id,
                    'name' => $city->name,
                    'city_name' => $city->region->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.city', ['city' => $query['id']]),
                        'delete_route' => route('delete.city', ['city' => $query['id']]),
                        'edit_permission' => 'edit-city',
                        'delete_permission' => 'delete-city',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.city.index');
    }

    public function edit(City $city)
    {
        if (!$this->authorize('edit-city')) {
            abort(403);
        }
        $regions = Region::all();
        return view('admin.city.edit', ['regions' => $regions, 'cities' => $city]);
    }

    public function update(Request $req, City $city)
    {
        if (!$this->authorize('edit-city')) {
            abort(403);
        }
        $city->name = $req->name;
        $city->region_id = $req->region;
        $city->save();

        toast('city updated', 'success');
        return redirect()->route('cities');
    }

    public function delete(City $city)
    {
        if (!$this->authorize('delete-city')) {
            abort(403);
        }
        $city->delete();
        toast('city Deleted!', 'success');
        return redirect()->back();
    }

    public function create(Region $region)
    {
        if (!$this->authorize('create-city')) {
            abort(403);
        }
        $regions = $region->all();
        return view('admin.city.form', ['regions' => $regions]);
    }

    public function store(City $city, CityStoreRequest $req)
    {
        if (!$this->authorize('create-city')) {
            abort(403);
        }
        $city->name = $req->name;
        $city->region_id = $req->region;
        $city->save();
        toast('City Created Successfully!', 'success');
        return redirect()->route('cities');
    }
}
