<?php

namespace App\Http\Controllers;

use App\Http\Requests\CountryStoreRequest;
use App\Models\Country;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class CountryController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-country')) {
            abort(403);
        }
        if ($req->ajax()) {

            $countries = Country::all();

            $table_data = [];

            foreach ($countries as $country) {
                $table_data[] = [
                    'id' => $country->id,
                    'name' => $country->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.country', ['country' => $query['id']]),
                        'delete_route' => route('delete.country', ['country' => $query['id']]),
                        'edit_permission' => 'edit-country',
                        'delete_permission' => 'delete-country',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.country.index');
    }

    public function edit(Country $country)
    {
        if (!$this->authorize('edit-country')) {
            abort(403);
        }
        return view('admin.country.edit', ['countries' => $country]);
    }

    public function update(Request $req, Country $country)
    {
        if (!$this->authorize('edit-country')) {
            abort(403);
        }
        $country->name = $req['name'];
        $country->save();

        toast('Country updated', 'success');
        return redirect()->route('countries');
    }

    public function delete(Country $country)
    {
        if (!$this->authorize('delete-country')) {
            abort(403);
        }
        $country->delete();
        toast('Country Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-country')) {
            abort(403);
        }
        return view('admin.country.form');
    }

    public function store(CountryStoreRequest $req)
    {
        if (!$this->authorize('create-country')) {
            abort(403);
        }
        $input = $req->all();
        Country::create($input);
        toast('Country Created Successfully!', 'success');
        return redirect()->route('countries');
    }
}
