<?php

namespace App\Http\Controllers;

use App\Models\Asset;
use App\Models\Entity;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;

class DashboardController extends Controller
{
    public function home()
    {
        if (Auth::user()->hasRole(User::SUPER_ADMIN_ROLE)) {
            $assets = Asset::all();
            $users = User::all();
        } elseif (Auth::user()->hasRole(User::SUPERVISOR_ROLE) && Auth::user()->hasRole(User::DATA_ENTRY_ROLE)) {
            $assets = Asset::where(function ($query) {
                $query->where('region', Auth::user()->region)
                    ->orWhere('asset_assign', Auth::user()->username);
            })->orderBy('created_at', 'desc');
            $assets = $assets->get();
            $users = User::where('region', Auth::user()->region)->get();
        } elseif (Auth::user()->hasRole(User::SUPERVISOR_ROLE)) {
            $assets = Asset::where('region', Auth::user()->region)->get();
            $users = User::where('region', Auth::user()->region)->get();
        } elseif (Auth::user()->hasRole(User::DATA_ENTRY_ROLE)) {
            $assets = Asset::where('asset_assign', Auth::user()->username)->get();
            $users = 0;
        } elseif (Auth::user()->hasRole(User::FIELD_USER_ROLE)) {
            $assets = Asset::where('asset_owner', Auth::user()->username)->orWhere('flag', 'Not Clear')->where('asset_owner', Auth::user()->username)->get();
            $users = 0;
        }

        $remainingAssets = Asset::whereNull('asset_assign')->count();
        $entities = Entity::all()->count();
        $userAssignAssets = Asset::where('asset_assign', Auth::user()->username)->count();
        return view('admin.dashboard', compact('assets', 'users', 'remainingAssets', 'entities', 'userAssignAssets'));
    }
}
