<?php

namespace App\Http\Controllers;

use App\Http\Requests\EntityStoreRequest;
use App\Models\Entity;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class EntityController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-entity')) {
            abort(403);
        }
        if ($req->ajax()) {

            $entities = Entity::all();
            $table_data = [];

            foreach ($entities as $entity) {
                $table_data[] = [
                    'id' => $entity->id,
                    'entity_code' => $entity->entity_code,
                    'entity_name' => $entity->entity_name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.entity', ['entity' => $query['id']]),
                        'delete_route' => route('delete.entity', ['entity' => $query['id']]),
                        'edit_permission' => 'edit-entity',
                        'delete_permission' => 'delete-entity',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.entities.index');
    }

    public function edit(Entity $entity)
    {
        if (!$this->authorize('edit-entity')) {
            abort(403);
        }
        return view('admin.entities.edit', ['entity' => $entity]);
    }

    public function update(Request $req, Entity $entity)
    {
        if (!$this->authorize('edit-entity')) {
            abort(403);
        }
        $entity->entity_code = $req['entity_code'];
        $entity->entity_name = $req['entity_name'];
        $entity->save();

        toast('Entity updated', 'success');
        return redirect()->route('entities');
    }

    public function delete(Entity $entity)
    {
        if (!$this->authorize('delete-entity')) {
            abort(403);
        }
        $entity->delete();
        toast('Entity Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-entity')) {
            abort(403);
        }
        return view('admin.entities.form');
    }

    public function store(EntityStoreRequest $req)
    {
        if (!$this->authorize('create-entity')) {
            abort(403);
        }
        $input = $req->all();
        Entity::create($input);
        toast('Entity Created Successfully!', 'success');
        return redirect()->route('entities');
    }
}
