<?php

namespace App\Http\Controllers;

use App\Http\Requests\Level1StoreRequest;
use App\Models\Level1;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class Level1Controller extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-level1')) {
            abort(403);
        }
        if ($req->ajax()) {

            $level1s = Level1::all();
            $table_data = [];
            foreach ($level1s as $level1) {
                $table_data[] = [
                    'id' => $level1->id,
                    'name' => $level1->name,
                    'name_ar' => $level1->name_ar,
                    'code' => $level1->code,

                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.level1', ['level1' => $query['id']]),
                        'delete_route' => route('delete.level1', ['level1' => $query['id']]),
                        'edit_permission' => 'edit-level1',
                        'delete_permission' => 'delete-level1',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.level1.index');
    }

    public function edit(Level1 $level1)
    {
        if (!$this->authorize('edit-level1')) {
            abort(403);
        }
        return view('admin.level1.edit', ['level1' => $level1]);
    }

    public function update(Request $req, Level1 $level1)
    {
        if (!$this->authorize('edit-level1')) {
            abort(403);
        }
        $level1->name = $req['name'];
        $level1->name_ar = $req['name_ar'];
        $level1->code = $req['code'];
        $level1->save();

        toast('Level 1 Data updated!', 'success');
        return redirect()->route('level1');
    }

    public function delete(Level1 $level1)
    {
        if (!$this->authorize('delete-level1')) {
            abort(403);
        }
        $level1->delete();
        toast('level1 Data Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-level1')) {
            abort(403);
        }
        return view('admin.level1.form');
    }

    public function store(Level1StoreRequest $req)
    {
        if (!$this->authorize('create-level1')) {
            abort(403);
        }
        $input = $req->all();
        Level1::create($input);

        toast('Level 1 Created Successfully!', 'success');
        return redirect()->route('level1');
    }
}
