<?php

namespace App\Http\Controllers;

use App\Http\Requests\Level2StoreRequest;
use App\Models\Level1;
use App\Models\Level2;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Monolog\Level;
use Yajra\DataTables\DataTables;

class Level2Controller extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-level2')) {
            abort(403);
        }
        if ($req->ajax()) {

            $level2s = Level2::all();
            $table_data = [];
            foreach ($level2s as $level2) {
                $table_data[] = [
                    'id' => $level2->id,
                    'name' => $level2->name,
                    'name_ar' => $level2->name_ar,
                    'level1' => $level2->level1->name,
                    'main_code' => $level2->level1->code . $level2->code,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.level2', ['level2' => $query['id']]),
                        'delete_route' => route('delete.level2', ['level2' => $query['id']]),
                        'edit_permission' => 'edit-level2',
                        'delete_permission' => 'delete-level2',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.level2.index');
    }

    public function edit(Level2 $level2)
    {
        if (!$this->authorize('edit-level2')) {
            abort(403);
        }
        $level1s = Level1::all();
        return view('admin.level2.edit', ['level2' => $level2, 'level1s' => $level1s]);
    }

    public function update(Request $req, level2 $level2)
    {
        if (!$this->authorize('edit-level2')) {
            abort(403);
        }
        $level2->name = $req['name'];
        $level2->name_ar = $req['name_ar'];
        $level2->code = $req['code'];
        $level2->level1_id = $req['level1'];
        $level2->save();

        toast('Level 2 Data updated!', 'success');
        return redirect()->route('level2');
    }

    public function delete(level2 $level2)
    {
        if (!$this->authorize('delete-level2')) {
            abort(403);
        }
        $level2->delete();
        toast('level2 Data Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-level2')) {
            abort(403);
        }
        $level1s = Level1::all();
        return view('admin.level2.form', ['level1s' => $level1s]);
    }

    public function store(Level2StoreRequest $req)
    {
        if (!$this->authorize('create-level2')) {
            abort(403);
        }
        $input = $req->all();

        level2::create([
            'name' => $input['name'],
            'name_ar' => $input['name_ar'],
            'code' => $input['code'],
            'level1_id' => $input['level1'],
        ]);

        toast('Level 2 Created Successfully!', 'success');
        return redirect()->route('level2');
    }
}
