<?php

namespace App\Http\Controllers;

use App\Http\Requests\Level3StoreRequest;
use App\Models\Level2;
use App\Models\Level3;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class Level3Controller extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-level3')) {
            abort(403);
        }
        if ($req->ajax()) {

            $level3s = Level3::with('Level2.Level1')->get();
            $table_data = [];
            foreach ($level3s as $level3) {
                $table_data[] = [
                    'id' => $level3->id,
                    'name' => $level3->name,
                    'name_ar' => $level3->name_ar,
                    'level2' => $level3->Level2->name,
                    'main_code' => $level3->level2->level1->code . $level3->Level2->code . $level3->code,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.level3', ['level3' => $query['id']]),
                        'delete_route' => route('delete.level3', ['level3' => $query['id']]),
                        'edit_permission' => 'edit-level3',
                        'delete_permission' => 'delete-level3',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.level3.index');
    }

    public function edit(Level3 $level3)
    {
        if (!$this->authorize('edit-level3')) {
            abort(403);
        }
        $level2s = Level2::all();
        return view('admin.level3.edit', ['level3' => $level3, 'level2s' => $level2s]);
    }

    public function update(Request $req, level3 $level3)
    {
        if (!$this->authorize('edit-level3')) {
            abort(403);
        }
        $level3->name = $req['name'];
        $level3->name_ar = $req['name_ar'];
        $level3->code = $req['code'];
        $level3->level2_id = $req['level2'];
        $level3->save();

        toast('Level 3 Data updated!', 'success');
        return redirect()->route('level3');
    }

    public function delete(level3 $level3)
    {
        if (!$this->authorize('delete-level3')) {
            abort(403);
        }
        $level3->delete();
        toast('level 3 Data Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-level3')) {
            abort(403);
        }
        $level2s = Level2::all();
        return view('admin.level3.form', ['level2s' => $level2s]);
    }

    public function store(Level3StoreRequest $req)
    {
        if (!$this->authorize('create-level3')) {
            abort(403);
        }
        $input = $req->all();

        level3::create([
            'name' => $input['name'],
            'name_ar' => $input['name_ar'],
            'code' => $input['code'],
            'level2_id' => $input['level2'],
        ]);

        toast('Level 3 Created Successfully!', 'success');
        return redirect()->route('level3');
    }
}
