<?php

namespace App\Http\Controllers;

use App\Http\Requests\Level4StoreRequest;
use App\Models\Level1;
use App\Models\Level2;
use App\Models\Level3;
use App\Models\Level4;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class Level4Controller extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-level4')) {
            abort(403);
        }
        if ($req->ajax()) {

            $level4s = Level4::all();
            $table_data = [];
            foreach ($level4s as $level4) {
                $table_data[] = [
                    'id' => $level4->id,
                    'name' => $level4->name,
                    'name_ar' => $level4->name_ar,
                    'code' => $level4->code,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.level4', ['level4' => $query['id']]),
                        'delete_route' => route('delete.level4', ['level4' => $query['id']]),
                        'edit_permission' => 'edit-level4',
                        'delete_permission' => 'delete-level4',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.level4.index');
    }

    public function edit(Level4 $level4)
    {
        if (!$this->authorize('edit-level4')) {
            abort(403);
        }
        $level3s = Level3::all();
        return view('admin.level4.edit', ['level4s' => $level4, 'level3s' => $level3s]);
    }

    public function update(Request $req, level4 $level4)
    {
        if (!$this->authorize('edit-level4')) {
            abort(403);
        }
        $level4->name = $req['name'];
        $level4->name_ar = $req['name_ar'];
        $level4->code = $req['code'];
        $level4->save();

        toast('Level 4 Data updated!', 'success');
        return redirect()->route('level4');
    }

    public function delete(level4 $level4)
    {
        if (!$this->authorize('delete-level4')) {
            abort(403);
        }
        $level4->delete();
        toast('level 4 Data Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-level4')) {
            abort(403);
        }
        $level3s = Level3::all();
        return view('admin.level4.form', ['level3s' => $level3s]);
    }

    public function store(Level4StoreRequest $req)
    {
        if (!$this->authorize('create-level4')) {
            abort(403);
        }
        $input = $req->all();

        level4::create([
            'name' => $input['name'],
            'name_ar' => $input['name_ar'],
            'code' => $input['code'],
        ]);

        toast('Level 4 Created Successfully!', 'success');
        return redirect()->route('level4');
    }
}
