<?php

namespace App\Http\Controllers;

use App\Http\Requests\PermissionStoreRequest;
use App\Models\Permission;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class PermissionController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-permission')) {
            abort(403);
        }
        if ($req->ajax()) {
            $permissions = Permission::all();

            $table_data = [];
            foreach ($permissions as $data) {
                $table_data[] = [
                    'id' => $data->id,
                    'name' => $data->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.permission', ['permission' => $query['id']]),
                        'delete_route' => route('delete.permission', ['permission' => $query['id']]),
                        'edit_permission' => 'edit-permission',
                        'delete_permission' => 'delete-permission',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.permissions.index');
    }

    public function create()
    {
        if (!$this->authorize('create-permission')) {
            abort(403);
        }
        return view('admin.permissions.form');
    }

    public function store(PermissionStoreRequest $req)
    {
        if (!$this->authorize('create-permission')) {
            abort(403);
        }
        $input = $req->all();
        Permission::create($input);

        toast('Permission Created Successfully!', 'success');
        return redirect()->route('permissions');
    }

    public function delete(Permission $permission)
    {
        if (!$this->authorize('delete-permission')) {
            abort(403);
        }
        $permission->delete();
        toast('Permission Deleted!', 'success');
        return redirect()->back();
    }

    public function edit(Permission $permission)
    {
        if (!$this->authorize('edit-permission')) {
            abort(403);
        }
        return view('admin.permissions.edit', ['permission' => $permission]);
    }

    public function update(Request $req, Permission $permission)
    {
        if (!$this->authorize('edit-permission')) {
            abort(403);
        }
        $permission->name = $req['name'];
        $permission->save();

        toast('Permission updated', 'success');
        return redirect()->route('permissions');
    }
}
