<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\AssetsExport;
use App\Http\Requests\ProjectReportRequest;
use App\Models\Asset;
use App\Models\Status;
use Carbon\Carbon;

class ProjectReportController extends Controller
{
    public function projectReport()
    {
        if (!$this->authorize('export-asset')) {
            abort(403);
        }
        $status = Status::all();

        return view('admin.project-report.project_report', compact('status'));
    }

    public function exportProjectReport(ProjectReportRequest $req)
    {
        if (!$this->authorize('export-asset')) {
            abort(403);
        }

        // Convert start_date and end_date to Carbon objects
        $startDate = Carbon::createFromFormat('Y-m-d', $req->start_date)->startOfDay();
        $endDate = Carbon::createFromFormat('Y-m-d', $req->end_date)->endOfDay();

        if ($req->admin_status == 'all') {
            $assets = Asset::whereBetween('created_at', [$startDate, $endDate])
                ->get();
        } else {
            // Retrieve assets based on provided dates and other criteria
            $assets = Asset::whereBetween('created_at', [$startDate, $endDate])
                ->where('admin_status', $req->admin_status)
                ->get();
        }

        if (!$assets->isEmpty()) {

            $assetIds = $assets->pluck('id')->toArray();
            $assetIdsString = implode(',', $assetIds);

            session()->forget('asset_ids');
            session(['asset_ids' => $assetIdsString]);

            return redirect()->route('export.asset');
        } else {
            toast('Asset Not Found!', 'error');
            return redirect()->back();
        }
    }
}
