<?php

namespace App\Http\Controllers;

use App\Http\Requests\RegionStoreRequest;
use App\Models\Country;
use App\Models\Region;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Symfony\Component\Console\Input\Input;
use Yajra\DataTables\DataTables;

class RegionController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-region')) {
            abort(403);
        }
        if ($req->ajax()) {

            $regions = Region::all();
            $table_data = [];

            foreach ($regions as $region) {
                $table_data[] = [
                    'id' => $region->id,
                    'name' => $region->name,
                    'country_name' => $region->country->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.region', ['region' => $query['id']]),
                        'delete_route' => route('delete.region', ['region' => $query['id']]),
                        'edit_permission' => 'edit-region',
                        'delete_permission' => 'delete-region',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.region.index');
    }

    public function edit(Region $region)
    {
        if (!$this->authorize('edit-region')) {
            abort(403);
        }
        $countries = Country::all();

        return view('admin.region.edit', ['regions' => $region, 'countries' => $countries]);
    }

    public function update(Request $req, Region $region)
    {
        if (!$this->authorize('edit-region')) {
            abort(403);
        }
        $region->name = $req->name;
        $region->country_id = $req->country;
        $region->save();

        toast('Region updated', 'success');
        return redirect()->route('regions');
    }

    public function delete(Region $region)
    {
        if (!$this->authorize('delete-region')) {
            abort(403);
        }
        $region->delete();
        toast('Region Deleted!', 'success');
        return redirect()->back();
    }

    public function create(Country $country)
    {
        if (!$this->authorize('create-region')) {
            abort(403);
        }
        $countries = $country->all();
        return view('admin.region.form', ['countries' => $countries]);
    }

    public function store(Region $region, RegionStoreRequest $req)
    {
        if (!$this->authorize('create-region')) {
            abort(403);
        }
        $region->name = $req->name;
        $region->country_id = $req->country;
        $region->save();
        toast('Region Created Successfully!', 'success');
        return redirect()->route('regions');
    }
}
