<?php

namespace App\Http\Controllers;

use App\Http\Requests\StatusStoreRequest;
use App\Models\Status;
use Illuminate\Http\Request;
use Illuminate\Database\Eloquent\Collection;
use Yajra\DataTables\DataTables;

class StatusController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-country')) {
            abort(403);
        }
        if ($req->ajax()) {

            $statuses = Status::all();

            $table_data = [];

            foreach ($statuses as $status) {
                $table_data[] = [
                    'id' => $status->id,
                    'name' => $status->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.status', ['status' => $query['id']]),
                        'delete_route' => route('delete.status', ['status' => $query['id']]),
                        'edit_permission' => 'edit-status',
                        'delete_permission' => 'delete-status',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.status.index');
    }

    public function edit(Status $status)
    {
        if (!$this->authorize('edit-status')) {
            abort(403);
        }
        return view('admin.status.edit', compact('status'));
    }

    public function update(Request $req, Status $status)
    {
        if (!$this->authorize('edit-status')) {
            abort(403);
        }

        if ($status->name == 'Complete 🟢') {
            toast('You Cannot edit/update (Complete 🟢) status value', 'error');
            return redirect()->back();
        }

        $status->name = $req['name'];
        $status->save();

        toast('Status updated', 'success');
        return redirect()->route('status');
    }

    public function delete(Status $status)
    {
        if (!$this->authorize('delete-status')) {
            abort(403);
        }

        if ($status->name == 'Complete 🟢') {
            toast('You Cannot delete (Complete 🟢) status value', 'error');
            return redirect()->back();
        }

        $status->delete();
        toast('Status Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-status')) {
            abort(403);
        }
        return view('admin.status.form');
    }

    public function store(StatusStoreRequest $req)
    {
        if (!$this->authorize('create-status')) {
            abort(403);
        }
        $input = $req->all();
        Status::create($input);
        toast('Status Created Successfully!', 'success');
        return redirect()->route('status');
    }
}
