<?php

namespace App\Http\Controllers;

use App\Http\Requests\ValuationMethodStoreRequest;
use App\Models\ValuationMethod;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class ValuationMethodController extends Controller
{
    public function index(Request $req)
    {
        if (!$this->authorize('list-valuation_method')) {
            abort(403);
        }
        if ($req->ajax()) {

            $valuations = ValuationMethod::all();
            $table_data = [];

            foreach ($valuations as $valuation) {
                $table_data[] = [
                    'id' => $valuation->id,
                    'name' => $valuation->name,
                ];
            }
            $collection = new Collection($table_data);
            return DataTables::of($collection)
                ->addIndexColumn()
                ->addColumn('action', function ($query) {
                    return view('admin.partials.action', [
                        'edit_route' => route('edit.valuation', ['valuation' => $query['id']]),
                        'delete_route' => route('delete.valuation', ['valuation' => $query['id']]),
                        'edit_permission' => 'edit-valuation_method',
                        'delete_permission' => 'delete-valuation_method',
                    ]);
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.valuation-method.index');
    }

    public function edit(ValuationMethod $valuation)
    {
        if (!$this->authorize('edit-valuation_method')) {
            abort(403);
        }
        return view('admin.valuation-method.edit', ['valuation' => $valuation]);
    }

    public function update(Request $req, ValuationMethod $valuation)
    {
        if (!$this->authorize('edit-valuation_method')) {
            abort(403);
        }
        $valuation->name = $req->name;
        $valuation->save();

        toast('Valuation Method updated!', 'success');
        return redirect()->route('valuations');
    }

    public function delete(ValuationMethod $valuation)
    {
        if (!$this->authorize('delete-valuation_method')) {
            abort(403);
        }
        $valuation->delete();
        toast('Valuation Method Deleted!', 'success');
        return redirect()->back();
    }

    public function create()
    {
        if (!$this->authorize('create-valuation_method')) {
            abort(403);
        }
        return view('admin.valuation-method.form');
    }

    public function store(ValuationMethod $valuation, ValuationMethodStoreRequest $req)
    {
        if (!$this->authorize('create-valuation_method')) {
            abort(403);
        }
        $valuation->name = $req->name;
        $valuation->save();
        toast('Valuation Method Created Successfully!', 'success');
        return redirect()->route('valuations');
    }
}
