<?php

namespace App\Imports;

use App\Models\Asset;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\ToCollection;
use Illuminate\Validation\ValidationException;
use Illuminate\Support\Facades\Log;
use Maatwebsite\Excel\Concerns\WithCalculatedFormulas;

class ImportAsset implements ToCollection
{
    /**
     * Import assets from Excel collection.
     *
     * @param Collection $rows
     * @return void
     */

    public $columnMapping = [
        'id' => 0,
        'asset_type' => 1,
        'entity' => 2,
        'entity_code' => 3,
        'asset_description' => 4,
        'accounting_group_arabic_description' => 5,
        'accounting_group_english_description' => 6,
        'accounting_group_code' => 7,
        'remaining_useful_life' => 8,
        'useful_life' => 9,
        'asset_owner' => 10,
        'assign_by' => 11,
        'country' => 12,
        'region' => 13,
        'city' => 14,
        'building_number' => 15,
        'floor_number' => 16,
        'room_office_number' => 17,
        'acquisition_method' => 18,
        'date_placed_in_service' => 19,
        'acquisition_date' => 20,
        'acquisition_cost' => 21,
        'archive_document_number' => 22,
        'asset_condition' => 23,
        'tag_number' => 24,
        'inspection_date' => 25,
        'valuation_method' => 26,
        'valuation_report_date' => 27,
        'opening_balance_date' => 28,
        'asset_opening_value' => 29,
        'valuation_report_reference' => 30,
        'base_unit_of_measure' => 31,
        'quantity' => 32,
        'unique_factory_id' => 33,
        'geographical_coordinates' => 34,
        'manufacturer' => 35,
        'model' => 36,
        'level1' => 37,
        'level2' => 38,
        'level3' => 39,
        'level4' => 40,
        'longitute' => 41,
        'latitude' => 42,
        'user_status' => 43,
        'admin_status' => 44,
        'asset_assign' => 45,
        'created_at' => 46,
        'updated_at' => 47,
    ];


    public function collection(Collection $rows)
    {
        try {
            foreach ($rows as $index => $row) {
                // Skip the first row if it contains column headers
                if ($index === 0) {
                    continue;
                }

                // Initialize an empty array to store asset data
                $assetData = [];

                // Map Excel columns to database columns based on the mapping configuration
                foreach ($this->columnMapping as $dbColumn => $excelColumnIndex) {
                    $assetData[$dbColumn] = $row[$excelColumnIndex];
                }

                // Create the asset using the mapped data
                Asset::create($assetData);
                toast('Asset imported!', 'success');
            }
        } catch (\Illuminate\Database\QueryException $e) {
            if ($e->errorInfo[1] == 1062) {
                // Unique constraint violation error
                return redirect()->back()->withErrors(["Make sure your asset fields are unique. Asset Barcode: " . $row[24]])->withInput();
            } else {
                // Other database related errors
                Log::error($e);
                return redirect()->back()->withErrors(["An error occurred while importing assets. Please try again later."])->withInput();
            }
        } catch (\Exception $e) {
            // Other generic exceptions
            Log::error($e);
            return redirect()->back()->withErrors(["An unexpected error occurred. Please try again later."])->withInput();
        }
    }
}
