<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Department extends Model
{
    use HasFactory;

    protected $guarded = [];

    public function assets()
    {
        return $this->hasMany(Asset::class);
    }

    public function parent()
    {
        return $this->belongsTo(Department::class, 'departments_id');
    }

    public function children()
    {
        return $this->hasMany(Department::class, 'departments_id');
    }

    public function childrenRecursive()
    {
        return $this->children()->with('childrenRecursive');
    }

    public function fullHierarchy()
    {
        return $this->childrenRecursive();
    }

    public static function getFullHierarchy(Department $department, $prefix = '')
    {
        $hierarchy = $prefix . $department->name;
        foreach ($department->children as $child) {
            $hierarchy .= "\n" . self::getFullHierarchy($child, $prefix . ' / ' . $department->name);
        }
        return $hierarchy;
    }

    private function addDepartmentHierarchy(&$table_data, $department, $parent_name = '', $full_name = '')
    {
        $full_name = $full_name ? $full_name . ' / ' . $department->name : $department->name;

        $table_data[] = [
            'id' => $department->id,
            'name' => $department->name,
            'parent_name' => $parent_name,
            'full_name' => $full_name
        ];

        foreach ($department->children as $child) {
            $this->addDepartmentHierarchy($table_data, $child, $department->name, $full_name);
        }
    }

    public static function getFullName(Department $department)
    {
        $full_name = $department->name;
        $parent = $department->parent;

        while ($parent) {
            $full_name = $parent->name . ' / ' . $full_name;
            $parent = $parent->parent;
        }

        return $full_name;
    }
}
