@extends('admin.layout.master')
@section('title', 'Create Assets')
@section('section', __('asset.Please Add Asset Information'))

@section('body')

    @if ($errors->any())
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif

    <div class="card card-danger">
        <div class="card-header">
            <h2>@lang('asset.Create Asset')</h2>
        </div>
        <div class="card-body">
            <form method="POST" action="{{ route('store.asset') }}" enctype="multipart/form-data">
                @csrf
                <div class="row">
                    <div class="form-group col-6">
                        <label for="asset_type">@lang('asset.Asset Type')</label>
                        <select id="asset_type" class="form-control select2" name="asset_type" autofocus>
                            <option value="" disabled selected>Choose...</option>
                            <option value="furniture" @if ($type == 'furniture') selected @endif>Furniture</option>
                            <option value="plantAndMachinery" @if ($type == 'plantAndMachinery') selected @endif>Plant &
                                Machinery</option>
                        </select>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse">
                        <h4 id="grab-me">@lang('asset.Basic Information')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-info"></i></a>
                        </div>
                    </div>
                    <div class="collapse show" id="mycard-collapse" style="">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="entity">@lang('asset.Entity') <small class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('entity') is-invalid @enderror"
                                        name="entity">
                                        <option value="" disabled>Choose...</option>
                                        @foreach ($entities as $entity)
                                            <option value="{{ $entity->id }}"
                                                @if (old('entity') == $entity->id) selected @endif>
                                                {{ $entity->entity_name }} ({{ $entity->entity_code }})
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('entity')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Quantity') <small class="text-danger">*</small></label>
                                    <input id="name" type="number" value="{{ old('quantity') }}"
                                        class="form-control @error('quantity') is-invalid @enderror" name="quantity"
                                        autofocus>
                                    @error('quantity')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">

                                <div class="form-group col-6">
                                    <label for="asset_description">@lang('asset.Asset Description')</label>
                                    <select class="form-control select2 @error('asset_description') is-invalid @enderror"
                                        name="asset_description" id="asset_description">
                                        <option value="" disabled>Choose...</option>
                                        @foreach ($descriptions as $desc)
                                            <option value="{{ $desc }}"
                                                @if (old('asset_description') == $desc) selected @endif>{{ $desc }}
                                            </option>
                                        @endforeach
                                        <option value="other" @if (old('asset_description') == 'other') selected @endif>Other
                                        </option>
                                    </select>
                                    @error('asset_description')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6" id="new_descripiton" style="display: none">
                                    <label for="new_descripiton">@lang('asset.New Asset Description')</label>
                                    <textarea class="form-control @error('new_descripiton') is-invalid @enderror" id="new_descripiton" rows="3"
                                        name="new_descripiton">{{ old('new_descripiton') }}</textarea>
                                    @error('new_descripiton')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="assign_by">@lang('asset.Assign By')</label>
                                    <input type="text" value="{{ old('assign_by', Auth::user()->username) }}"
                                        class="form-control @error('assign_by') is-invalid @enderror" name="assign_by"
                                        autofocus disabled>
                                    @error('assign_by')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="asset_type">@lang('asset.Tag Number') <small class="text-danger">*</small></label>
                                    <input type="text" class="@error('tags') is-invalid @enderror" name="tags"
                                        data-role="tagsinput" id="tags_id" value="{{ old('tags') }}">
                                    @error('tags')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label>@lang('asset.Inspection Date')</label>
                                    <input type="date" name="inspection_date" value="{{ $date }}"
                                        class="form-control datemask @error('inspection_date') is-invalid @enderror"
                                        placeholder="YYYY/MM/DD" disabled>
                                    @error('inspection_date')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label>@lang('asset.Date Placed in Service')</label>
                                    <input type="date" name="date_placed_in_service"
                                        value="{{ old('date_placed_in_service') }}"
                                        class="form-control datemask @error('date_placed_in_service') is-invalid @enderror"
                                        placeholder="YYYY/MM/DD">
                                    @error('date_placed_in_service')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Archive Document Number')</label>
                                    <input id="name" type="text" value="{{ old('archive_document_number') }}"
                                        class="form-control @error('archive_document_number') is-invalid @enderror"
                                        name="archive_document_number" autofocus>
                                    @error('archive_document_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6"
                                    @if (!Auth::user()->hasRole(\App\Models\User::SUPER_ADMIN_ROLE)) style="display: none" @endif>
                                    <label for="admin_status">@lang('asset.Status') <small
                                            class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('admin_status') is-invalid @enderror"
                                        name="admin_status" id="admin_status">
                                        <option value="" disabled>Choose...</option>
                                        @foreach ($statuses as $status)
                                            <option value="{{ $status->name }}"
                                                @if (old('admin_status') == $status->name) selected @endif>{{ $status->name }}
                                            </option>
                                        @endforeach
                                        <option value="other" @if (old('admin_status') == 'other') selected @endif>Other
                                        </option>
                                    </select>
                                    @error('admin_status')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6" id="customStatusContainer" style="display: none;">
                                    <label>@lang('asset.Custom Status')</label>
                                    <input type="text" name="custom_status" id="custom_status"
                                        class="form-control @error('custom_status') is-invalid @enderror">
                                    @error('custom_status')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6"
                                    @if (Auth::user()->hasRole(\App\Models\User::SUPER_ADMIN_ROLE)) style="display: none" @endif>
                                    <label for="user_status">@lang('asset.User Status')</label>
                                    <select class="form-control select2" name="user_status">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($statuses as $status)
                                            <option value="{{ $status->name }}">{{ $status->name }}</option>
                                        @endforeach
                                    </select>
                                </div>

                                <div class="form-group col-6">
                                    <label for="asset_owner">@lang('asset.Asset Owner')</label>
                                    <select class="form-control select2 @error('asset_owner') is-invalid @enderror"
                                        name="asset_owner">
                                        <option value="" disabled>Choose...</option>
                                        @foreach ($users as $user)
                                            <option value="{{ $user->username }}"
                                                @if (old('asset_owner', Auth::user()->username) == $user->username) selected @endif>
                                                {{ $user->username }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('asset_owner')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Base Unit Of Measure')</label>
                                    <input id="name" type="text" value="{{ old('base_unit_of_measure') }}"
                                        class="form-control @error('base_unit_of_measure') is-invalid @enderror"
                                        name="base_unit_of_measure" autofocus>
                                    @error('base_unit_of_measure')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Employee Custody')</label>
                                    <input id="name" type="text" value="{{ old('employee_custody') }}"
                                        class="form-control @error('employee_custody') is-invalid @enderror"
                                        name="employee_custody" autofocus>
                                    @error('employee_custody')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                        </div>
                    </div>
                </div>


                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-1">
                        <h4 id="grab-me">@lang('asset.Classification')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-1" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-calendar"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-1">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="level1">@lang('asset.Level 1')</label>
                                    <select class="form-control select2 @error('level1') is-invalid @enderror"
                                        name="level1">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($level1s as $level1)
                                            <option value="{{ $level1->id }}"
                                                @if (old('level1') == $level1->id) selected @endif>
                                                {{ $level1->name_ar }} ({{ $level1->code }})
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('level1')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="level2">@lang('asset.Level 2')</label>
                                    <select class="form-control select2 @error('level2') is-invalid @enderror"
                                        name="level2">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($level2s as $level2)
                                            <option value="{{ $level2->id }}"
                                                @if (old('level2') == $level2->id) selected @endif>
                                                {{ $level2->name_ar }} ({{ $level2->code }})
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('level2')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="level3">@lang('asset.Level 3')</label>
                                    <select class="form-control select2 @error('level3') is-invalid @enderror"
                                        name="level3">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($level3s as $level3)
                                            <option value="{{ $level3->id }}"
                                                @if (old('level3') == $level3->id) selected @endif>
                                                {{ $level3->name_ar }} ({{ $level3->code }})
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('level3')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="level4">@lang('asset.Level 4')</label>
                                    <select class="form-control select2 @error('level4') is-invalid @enderror"
                                        name="level4">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($level4s as $level4)
                                            <option value="{{ $level4->id }}"
                                                @if (old('level4') == $level4->id) selected @endif>
                                                {{ $level4->name_ar }} ({{ $level4->code }})
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('level4')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>

                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="quick_add_code">@lang('asset.Quick Add Code')</label>
                                    <input type="number" id="quick_add_input" class="form-control"
                                        name="quick_add_code" autofocus>
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group">
                                    <label for="quick_add_button">&nbsp;</label>
                                    <a href="javascript:void(0);" id="quick_add_link" class="btn btn-danger">
                                        @lang('button.Quick Add')
                                    </a>
                                </div>
                                <div class="form-group">
                                    <label for="clear_fields_link">&nbsp;</label>
                                    <a href="javascript:void(0);" id="clear_fields_link" class="btn btn-secondary">
                                        @lang('button.Reset')
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-8">
                        <h4 id="grab-me">@lang('department.Departments')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-10" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-warehouse"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-8">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-12">
                                    <label for="department">@lang('department.Department')</label>
                                    <select class="form-control select2 @error('department') is-invalid @enderror"
                                        name="department">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($departments as $department)
                                            <option value="{{ $department['id'] }}"
                                                @if (old('department') == $department['id']) selected @endif>
                                                {{ $department['id'] }}. {{ $department['full_name'] }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('department')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-3">
                        <h4 id="grab-me">@lang('asset.Location')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-3" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-map-pin"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-3" style="">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="country">@lang('asset.Country') <small class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('country') is-invalid @enderror"
                                        name="country" id="country" autofocus>
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($countries as $country)
                                            <option value="{{ $country->id }}">
                                                {{ $country->name }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('country')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="region">@lang('asset.Region') <small class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('region') is-invalid @enderror"
                                        name="region" id="region">
                                        <option value="" disabled selected>Choose Country To Continue</option>
                                    </select>
                                    @error('region')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="city">@lang('asset.City') <small class="text-danger">*</small></label>
                                    <select class="form-control @error('city') is-invalid @enderror select2"
                                        name="city" id="city">
                                        <option value="" disabled selected>Choose Region To Continue</option>
                                    </select>
                                    @error('city')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Building Number') <small class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('building_number') is-invalid @enderror"
                                        name="building_number" id="building_number">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($buildings as $building)
                                            <option value="{{ $building }}"
                                                @if (old('building_number') == $building) selected @endif>{{ $building }}
                                            </option>
                                        @endforeach
                                        <option value="other" @if (old('building_number') == 'other') selected @endif>Other
                                        </option>

                                    </select>
                                    @error('building_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6" id="new_building_number" style="display: none;">
                                    <label for="name">@lang('asset.New Building Number') <small class="text-danger">*</small></label>
                                    <input id="name" type="text" value="{{ old('new_building_number') }}"
                                        class="form-control @error('new_building_number') is-invalid @enderror"
                                        name="new_building_number" autofocus>
                                    @error('new_building_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Floor Number') <small class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('floor_number') is-invalid @enderror"
                                        name="floor_number" id="floor_number">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($floors as $floor)
                                            <option value="{{ $floor }}"
                                                @if (old('floor_number') == $floor) selected @endif>{{ $floor }}
                                            </option>
                                        @endforeach
                                        <option value="other" @if (old('floor_number') == 'other') selected @endif>Other
                                        </option>
                                    </select>
                                    @error('floor_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6" id="new_floor_number" style="display: none;">
                                    <label for="name">@lang('asset.New Floor Number')</label>
                                    <input id="name" type="text" value="{{ old('new_floor_number') }}"
                                        class="form-control @error('new_floor_number') is-invalid @enderror"
                                        name="new_floor_number" autofocus>
                                    @error('new_floor_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>


                                <div class="form-group col-6">
                                    <label for="room_office_number">@lang('asset.Room/Office Number') <small
                                            class="text-danger">*</small></label>
                                    <select class="form-control select2 @error('room_office_number') is-invalid @enderror"
                                        name="room_office_number" id="room_office_number">
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($rooms as $room)
                                            <option value="{{ $room }}"
                                                @if (old('room_office_number') == $room) selected @endif>{{ $room }}
                                            </option>
                                        @endforeach
                                        <option value="other" @if (old('room_office_number') == 'other') selected @endif>Other
                                        </option>
                                    </select>
                                    @error('room_office_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6" id="new_room_office_number" style="display: none;">
                                    <label for="new_room_office_number">@lang('asset.New Room/Office Number')</label>
                                    <input id="new_room_office_number" type="text"
                                        value="{{ old('new_room_office_number') }}"
                                        class="form-control @error('new_room_office_number') is-invalid @enderror"
                                        name="new_room_office_number" autofocus>
                                    @error('new_room_office_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="longitute">@lang('asset.Longitude') <small class="text-danger">*</small></label>
                                    <input id="longitute" type="text" value="{{ old('longitute') }}"
                                        class="form-control @error('longitute') is-invalid @enderror" name="longitute"
                                        autofocus>
                                    @error('longitute')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="latitude">@lang('asset.Latitude') <small class="text-danger">*</small></label>
                                    <input id="latitude" type="text" value="{{ old('latitude') }}"
                                        class="form-control @error('latitude') is-invalid @enderror" name="latitude"
                                        autofocus>
                                    @error('latitude')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-4">
                        <h4 id="grab-me">@lang('asset.Accounting Information')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-4" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-info"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-4">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="accounting_group_arabic_description">@lang('asset.Accounting Group Arabic Description')</label>
                                    <textarea class="form-control @error('accounting_group_arabic_description') is-invalid @enderror" rows="3"
                                        name="accounting_group_arabic_description">{{ old('accounting_group_arabic_description') }}</textarea>
                                    @error('accounting_group_arabic_description')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="accounting_group_english_description">@lang('asset.Accounting Group English Description')</label>
                                    <textarea class="form-control @error('accounting_group_english_description') is-invalid @enderror" rows="3"
                                        name="accounting_group_english_description">{{ old('accounting_group_english_description') }}</textarea>
                                    @error('accounting_group_english_description')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="accounting_group_code">@lang('asset.Accounting Group Code')</label>
                                    <input type="number" value="{{ old('accounting_group_code') }}"
                                        class="form-control @error('accounting_group_code') is-invalid @enderror"
                                        name="accounting_group_code" autofocus>
                                    @error('accounting_group_code')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="remaining_useful_life">@lang('asset.Remaining Useful Life')</label>
                                    <input type="date" value="{{ old('remaining_useful_life') }}"
                                        class="form-control @error('remaining_useful_life') is-invalid @enderror"
                                        name="remaining_useful_life" autofocus>
                                    @error('remaining_useful_life')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">

                                <div class="form-group col-6">
                                    <label for="useful_life">@lang('asset.Useful Life')</label>
                                    <input type="number" value="{{ old('useful_life') }}"
                                        class="form-control @error('useful_life') is-invalid @enderror"
                                        name="useful_life" autofocus>
                                    @error('useful_life')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-5">
                        <h4 id="grab-me">@lang('asset.Asset Acquisition')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-5" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-shopping-bag"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-5">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Acquisition Method')</label>
                                    <input id="name" type="text" value="{{ old('acquisition_method') }}"
                                        class="form-control @error('acquisition_method') is-invalid @enderror"
                                        name="acquisition_method" autofocus>
                                    @error('acquisition_method')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label>@lang('asset.Acquisition Date')</label>
                                    <input type="date" name="acquisition_date" value="{{ old('acquisition_date') }}"
                                        class="form-control datemask @error('acquisition_date') is-invalid @enderror"
                                        placeholder="YYYY/MM/DD">
                                    @error('acquisition_date')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Acquisition Cost')</label>
                                    <input id="name" type="number" value="{{ old('acquisition_cost') }}"
                                        class="form-control @error('acquisition_cost') is-invalid @enderror"
                                        name="acquisition_cost" autofocus>
                                    @error('acquisition_cost')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Asset Condition')</label>
                                    <select id="name" value="{{ old('asset_condition') }}"
                                        class="form-control @error('asset_condition') is-invalid @enderror"
                                        name="asset_condition" autofocus>
                                        <option value="" disabled selected>Choose...</option>
                                        <option>Bad</option>
                                        <option>Good</option>
                                        <option>Very Good</option>
                                    </select>
                                    @error('asset_condition')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label for="supportive_document_for_acquisition_cost">@lang('asset.Supportive Documents For Acquisition Cost')</label>
                                    <input id="supportive_document_for_acquisition_cost" type="text"
                                        value="{{ old('supportive_document_for_acquisition_cost') }}"
                                        class="form-control @error('supportive_document_for_acquisition_cost') is-invalid @enderror"
                                        name="supportive_document_for_acquisition_cost" autofocus>
                                    @error('supportive_document_for_acquisition_cost')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>

                            <div class="card-body card-block">

                                <div class="row form-group">
                                    <div class="col-12 col-md-12">
                                        <div class="control-group" id="fields">
                                            <label class="control-label" for="field1">
                                                @lang('asset.Asset Images')
                                            </label>
                                            <div class="controls">
                                                <div class="entry input-group upload-input-group">
                                                    <input class="form-control" name="asset_images[]" type="file">
                                                    <button class="btn btn-upload btn-success btn-add" type="button">
                                                        <i class="fa fa-plus"></i>
                                                    </button>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-6">
                        <h4 id="grab-me">@lang('asset.Asset Valuation')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-6" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-universal-access"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-6">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Valuation Method')</label>
                                    <select id="name" value="{{ old('valuation_method') }}"
                                        class="form-control select2 @error('valuation_method') is-invalid @enderror"
                                        name="valuation_method" autofocus>
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($valuationMethods as $valuationMethod)
                                            <option value="{{ $valuationMethod->name }}"
                                                @if (old('valuation_method') == $valuationMethod->name) selected @endif>
                                                {{ $valuationMethod->name }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('valuation_method')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label>@lang('asset.Valuation Report Date')</label>
                                    <input type="date" name="valuation_report_date"
                                        value="{{ old('valuation_report_date') }}"
                                        class="form-control datemask @error('valuation_report_date') is-invalid @enderror"
                                        placeholder="YYYY/MM/DD">
                                    @error('valuation_report_date')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label>@lang('asset.Opening Balance Date')</label>
                                    <input type="date" name="opening_balance_date"
                                        value="{{ old('opening_balance_date') }}"
                                        class="form-control datemask @error('opening_balance_date') is-invalid @enderror"
                                        placeholder="YYYY/MM/DD">
                                    @error('opening_balance_date')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Asset Opening Value')</label>
                                    <input id="name" type="number" value="{{ old('asset_opening_value') }}"
                                        class="form-control @error('asset_opening_value') is-invalid @enderror"
                                        name="asset_opening_value" autofocus>
                                    @error('asset_opening_value')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="name">@lang('asset.Valuation Report Reference')</label>
                                    <input id="name" type="number"
                                        value="{{ old('valuation_report_reference') }}"
                                        class="form-control @error('valuation_report_reference') is-invalid @enderror"
                                        name="valuation_report_reference" autofocus>
                                    @error('valuation_report_reference')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="manufacturer">@lang('asset.Manufacturer')</label>
                                    <input id="manufacturer" type="text" value="{{ old('manufacturer') }}"
                                        class="form-control @error('manufacturer') is-invalid @enderror"
                                        name="manufacturer" autofocus>
                                    @error('manufacturer')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="form-group col-6">
                    <label for="serial_number">@lang('asset.Serial Number')</label>
                    <input id="serial_number" type="text" value="{{ old('serial_number') }}"
                        class="form-control @error('serial_number') is-invalid @enderror" name="serial_number" autofocus>
                    @error('serial_number')
                        <span class="invalid-feedback" role="alert">
                            <strong>{{ $message }}</strong>
                        </span>
                    @enderror
                </div>

                <div class="form-check mb-4">
                    <label class="form-check-label" for="flexCheckDefault">
                        <input class="form-check-input" type="checkbox" value="0" id="flexCheckDefault"
                            name="asset_have_serial_number">
                        @lang('asset.Asset No Serial Number')
                    </label>
                </div>


                <div class="row" id="plantAndMachinery" style="display: none;">
                    <div class="form-group col-6">
                        <label for="unique_factory_id">@lang('asset.Unique Factory Id')</label>
                        <input id="name" type="text" value="{{ old('unique_factory_id') }}"
                            class="form-control @error('unique_factory_id') is-invalid @enderror"
                            name="unique_factory_id" autofocus>
                        @error('unique_factory_id')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                    <div class="form-group col-6">
                        <label for="geographical_coordinates">@lang('asset.Geographical Coordinates')</label>
                        <input id="geographical_coordinates" type="number"
                            value="{{ old('geographical_coordinates') }}"
                            class="form-control @error('geographical_coordinates') is-invalid @enderror"
                            name="geographical_coordinates" autofocus>
                        @error('geographical_coordinates')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                    <div class="form-group col-6">
                        <label for="model">@lang('asset.Model')</label>
                        <input id="model" type="text" value="{{ old('model') }}"
                            class="form-control @error('model') is-invalid @enderror" name="model" autofocus>
                        @error('model')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                </div>
                <div class="form-group">
                    <button type="submit" class="btn btn-danger btn-lg btn-block">
                        @lang('button.Create')
                    </button>
                </div>
            </form>
        </div>
    </div>

    <script>
        $(document).ready(function() {
            alert($('#input').tagsinput('items'));
        });
    </script>

@endsection
