@extends('admin.layout.master')
@section('title', 'View Assets')
@section('section', __('asset.View Assets'))


@section('body')


    <div class="col-12">
        <div class="card">
            <div class="card-header">
                <h4>@lang('asset.Asset') <code>@lang('asset.Images')</code></h4>
            </div>
            <div class="card-body">
                <div class="gallery gallery-md">
                    @foreach ($asset->attachments as $attachment)
                        <div class="gallery-item" data-image="{{ Storage::url($attachment->url) }}"
                            data-title="Image {{ $loop->iteration }}" href="{{ Storage::url($attachment->url) }}"
                            title="Image {{ $loop->iteration }}"
                            style="background-image: url(&quot;{{ Storage::url($attachment->url) }}&quot;);">
                        </div>
                    @endforeach
                </div>
            </div>
        </div>
    </div>

    <div class="card card-danger">
        <div class="card-header">
            <h2>@lang('asset.Asset Details')</h2>
            @if (Auth::user()->hasRole(App\Models\User::DATA_ENTRY_ROLE))
                @if ($asset->flag == 'Not Clear' || $asset->flag == 'Pending')
                    <a href="{{ route('clear.asset', ['id' => $asset->id]) }}"><button class="btn btn-danger ml-2"
                            style="margin-bottom: 5px">@lang('button.Confirm Clear')</button></a>
                    <a href="{{ route('re_flag.asset', ['id' => $asset->id]) }}"><button class="btn btn-danger ml-2"
                            style="margin-bottom: 5px">@lang('button.Re Flag')</button></a>
                @elseif ($asset->flag == 'Clear')
                    <a href="{{ route('re_flag.asset', ['id' => $asset->id]) }}"><button class="btn btn-danger ml-2"
                            style="margin-bottom: 5px">@lang('button.Re Flag')</button></a>
                @else
                    <a href="{{ route('re_flag.asset', ['id' => $asset->id]) }}"><button class="btn btn-danger ml-2"
                            style="margin-bottom: 5px">@lang('button.Flag it')</button></a>
                @endif
            @endif
        </div>
        <div class="card-body">
            <div class="row">
                <!-- First Column -->
                <div class="col-md-4">
                    <ul class="list-group">
                        <li class="list-group-item"><strong>ID:</strong> {{ $asset->id }}</li>
                        <li class="list-group-item"><strong>Entity:</strong> {{ $asset->entity->entity_name }}
                            ({{ $asset->entity->entity_code }})</li>
                        <li class="list-group-item"><strong>Asset Type:</strong> {{ $asset->asset_type }}
                        </li>
                        <li class="list-group-item"><strong>Asset Description:</strong> {{ $asset->asset_description }}
                        </li>
                        <li class="list-group-item"><strong>Accounting Group (Arabic):</strong>
                            {{ $asset->accounting_group_arabic_description }}</li>
                        <li class="list-group-item"><strong>Accounting Group (English):</strong>
                            {{ $asset->accounting_group_english_description }}</li>
                        <li class="list-group-item"><strong>Accounting Group Code:</strong>
                            {{ $asset->accounting_group_code }}</li>
                        <li class="list-group-item"><strong>Remaining Useful Life:</strong>
                            {{ $asset->remaining_useful_life }}</li>
                        <li class="list-group-item"><strong>Useful Life:</strong> {{ $asset->useful_life }}</li>
                        <li class="list-group-item"><strong>Assign Owner:</strong> {{ $asset->asset_owner }}</li>
                        <li class="list-group-item"><strong>Assign By:</strong> {{ $asset->assign_by }}</li>
                        <li class="list-group-item"><strong>Asset Assign:</strong> {{ $asset->asset_assign }}</li>
                        <li class="list-group-item"><strong>Tag Number:</strong> {{ $asset->tag_number }}</li>
                        <li class="list-group-item"><strong>Country:</strong> {{ $asset->country }}</li>
                        <li class="list-group-item"><strong>Longitute:</strong> {{ $asset->longitute }}</li>
                        <li class="list-group-item"><strong>Latitude:</strong> {{ $asset->latitude }}</li>
                        <li class="list-group-item"><strong>Level 1:</strong>
                            @if ($level1Name)
                                {{ $level1Name->name }}
                            @endif
                        </li>
                        <li class="list-group-item"><strong>Level 2:</strong>
                            @if ($level2Name)
                                {{ $level2Name->name }}
                            @endif
                        </li>
                        <li class="list-group-item"><strong>Level 3:</strong>
                            @if ($level3Name)
                                {{ $level3Name->name }}
                            @endif
                        </li>
                        <li class="list-group-item"><strong>Level 4:</strong>
                            @if ($level4Name)
                                {{ $level4Name->name }}
                            @endif
                        </li>
                        <li class="list-group-item"><strong>Employee Custody:</strong> {{ $asset->employee_custody }}</li>

                    </ul>
                </div>

                <!-- Second Column -->
                <div class="col-md-4">
                    <ul class="list-group">
                        <li class="list-group-item"><strong>Region:</strong> {{ $asset->region }}</li>
                        <li class="list-group-item"><strong>City:</strong> {{ $asset->city }}</li>
                        <li class="list-group-item"><strong>Building Number:</strong> {{ $asset->building_number }}</li>
                        <li class="list-group-item"><strong>Floor Number:</strong> {{ $asset->floor_number }}</li>
                        <li class="list-group-item"><strong>Room/Office Number:</strong> {{ $asset->room_office_number }}
                        </li>
                        <li class="list-group-item"><strong>Acquisition Method:</strong> {{ $asset->acquisition_method }}
                        </li>
                        <li class="list-group-item"><strong>Date Placed in Service:</strong>
                            {{ $asset->date_placed_in_service }}</li>
                        <li class="list-group-item"><strong>Acquisition Date:</strong> {{ $asset->acquisition_date }}</li>
                        <li class="list-group-item"><strong>Acquisition Cost:</strong> {{ $asset->acquisition_cost }}</li>
                        <li class="list-group-item">
                            <strong>Supportive Documents:</strong>
                            @if ($asset->attachments->isNotEmpty())
                                <ul>
                                    <button id="downloadAllButton"
                                        class="btn btn-danger btn-sm my-3">@lang('button.Download All')</button>

                                    @foreach ($asset->attachments as $attachment)
                                        <li>
                                            <a href="{{ Storage::url($attachment->url) }}" target="_blank">

                                                @php
                                                    $extension = pathinfo($attachment->url, PATHINFO_EXTENSION);
                                                    $iconClass = '';
                                                    $icon_color = '';

                                                    switch ($extension) {
                                                        case 'pdf':
                                                            $iconClass = 'bi bi-file-earmark-pdf-fill'; // Assuming you have Font Awesome icons
                                                            $icon_color = App\Models\Asset::PDF;
                                                            break;
                                                        case 'png':
                                                        case 'jpg':
                                                        case 'jpeg':
                                                            $iconClass = 'bi bi-images';
                                                            $icon_color = App\Models\Asset::PNG;
                                                            break;
                                                        case 'xlsx':
                                                            $iconClass = 'bi bi-file-earmark-spreadsheet-fill';
                                                            $icon_color = App\Models\Asset::EXCEL;
                                                            break;
                                                        // Add more cases for other file types
                                                        default:
                                                            $iconClass = 'far fa-file'; // Default icon for other file types
                                                    }
                                                @endphp
                                                <i class="{{ $iconClass }}" style="color: {{ $icon_color }};"></i>
                                            </a>
                                        </li>
                                    @endforeach
                                </ul>
                            @else
                                <p class="text-danger">No documents available.</p>
                            @endif
                        </li>
                    </ul>
                </div>

                <!-- Third Column -->
                <div class="col-md-4">
                    <ul class="list-group">
                        <li class="list-group-item"><strong>Archive Document Number:</strong>
                            {{ $asset->archive_document_number }}</li>
                        <li class="list-group-item"><strong>Asset Condition:</strong> {{ $asset->asset_condition }}
                        </li>
                        <li class="list-group-item"><strong>Inspection Date:</strong> {{ $asset->inspection_date }}
                        </li>
                        <li class="list-group-item"><strong>Valuation Method:</strong>
                            {{ $asset->valuation_method ?? 'Not specified' }}</li>
                        <li class="list-group-item"><strong>Valuation Report Date:</strong>
                            {{ $asset->valuation_report_date }}</li>
                        <li class="list-group-item"><strong>Opening Balance Date:</strong>
                            {{ $asset->opening_balance_date }}</li>
                        <li class="list-group-item"><strong>Asset Opening Value:</strong>
                            {{ $asset->asset_opening_value }}
                        </li>
                        <li class="list-group-item"><strong>Valuation Report Reference:</strong>
                            {{ $asset->valuation_report_reference }}</li>
                        <li class="list-group-item"><strong>Base Unit of Measure:</strong>
                            {{ $asset->base_unit_of_measure }}</li>
                        <li class="list-group-item"><strong>Quantity:</strong> {{ $asset->quantity }}</li>
                        <li class="list-group-item"><strong>Admin Status:</strong>{{ Str::ucfirst($asset->admin_status) }}
                        </li>
                        <li class="list-group-item"><strong>User Status:</strong>{{ Str::ucfirst($asset->user_status) }}
                        </li>
                        <li class="list-group-item"><strong>Asset Flag:</strong>
                            {{ $asset->flag }}</li>

                        <li class="list-group-item"><strong>Manufacturer:</strong> {{ $asset->manufacturer }}</li>


                        @if ($asset->asset_type == 'plantAndMachinery')
                            <li class="list-group-item"><strong>Unique factory id:</strong>
                                {{ $asset->unique_factory_id }}
                            </li>
                            <li class="list-group-item"><strong>Geographical coordinates:</strong>
                                {{ $asset->geographical_coordinates }}</li>
                            <li class="list-group-item"><strong>Model:</strong> {{ $asset->model }}</li>
                        @endif
                    </ul>
                </div>

            </div>
        </div>
    </div>

@section('my-js')
    <script>
        $(document).ready(function() {
            $('#downloadAllButton').on('click', function() {
                var attachments = {!! $asset->attachments->toJson() !!};

                if (attachments.length > 0) {
                    var filenames = attachments.map(function(attachment) {
                        return attachment.url;
                    });

                    // Create a hidden link element
                    var hiddenLink = document.createElement('a');
                    document.body.appendChild(hiddenLink);

                    // Counter to keep track of successful downloads
                    var successCount = 0;

                    // Iterate through each filename and trigger download
                    filenames.forEach(function(filename) {
                        hiddenLink.href = "{{ route('asset.bulk_download') }}?filename=" +
                            filename;
                        hiddenLink.download = filename;

                        hiddenLink.addEventListener('load', function() {
                            successCount++;
                            // Check if all files have been successfully downloaded
                            if (successCount === filenames.length) {
                                // Optionally, you can provide a feedback to the user
                                alert('All files downloaded successfully.');
                            }
                        });

                        hiddenLink.click();
                    });

                    // Remove the hidden link element
                    document.body.removeChild(hiddenLink);
                } else {
                    // Handle the case when there are no attachments
                    alert('No documents available for download.');
                }
            });
        });
    </script>
@endsection

@endsection
