@extends('admin.layout.master')
@section('title', 'Manage Users')
@section('section', __('user.Add User'))

@section('body')
    <div class="card card-danger">
        <div class="card-header">
            <h2>@lang('user.Add User')</h2>
        </div>
        <div class="card-body">
            <form method="POST" action="{{ route('store.user') }}">
                @csrf
                <div class="row">
                    <div class="form-group col-6">
                        <label for="name">@lang('user.Name')</label>
                        <input id="name" type="text" value="{{ old('name') }}"
                            class="form-control @error('name') is-invalid @enderror" name="name" autofocus>
                        @error('name')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                    <div class="form-group col-6">
                        <label for="username">@lang('user.Username')</label>
                        <input id="username" type="text" value="{{ old('username') }}"
                            class="form-control @error('username') is-invalid @enderror" name="username" autofocus>
                        @error('username')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                    <div class="form-group col-6">
                        <label for="phone">@lang('user.Phone #')</label>
                        <div class="input-group mb-3">
                            <div class="input-group-prepend">
                                <button id="countryCodeBtn" class="btn btn-outline-danger dropdown-toggle" type="button"
                                    data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">+966</button>
                                <div class="dropdown-menu">
                                    <a class="dropdown-item" href="#" data-code="+966">+966 (Saudi Arabia)</a>
                                    <a class="dropdown-item" href="#" data-code="+92">+92 (Pakistan)</a>
                                </div>
                            </div>
                            <input id="selectedCountryCode" type="hidden" name="country_code" value="+966">
                            <input id="phoneNumberInput" type="text"
                                class="form-control @error('phone') is-invalid @enderror" value="{{ old('phone') }}"
                                name="phone" aria-label="Text input with dropdown button"
                                placeholder="Enter Phone Number">
                            @error('phone')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>


                    <div class="col-6">
                        <div class="form-group">
                            <label for="email">@lang('user.Email')</label>
                            <input id="email" type="email" value="{{ old('email') }}"
                                class="form-control @error('email') is-invalid @enderror" name="email">
                            @error('email')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                    </div>
                    <div class="col-6">
                        <label for="password" class="d-block">@lang('user.Password')</label>
                        <div class="input-group">
                            <input id="password" type="password" value="{{ old('password') }}"
                                class="form-control @error('password') is-invalid @enderror" data-indicator="pwindicator"
                                name="password">
                            <div class="input-group-append">
                                <button class="btn btn-danger" type="button" id="togglePasswordVisibility">
                                    <i class="fas fa-eye" id="eyeIcon"></i>
                                </button>
                            </div>
                            <div class="input-group-append">
                                <button class="btn btn-danger" type="button" id="generatePasswordBtn">
                                    Generate
                                </button>
                            </div>
                            @error('password')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                            @enderror
                        </div>
                        <div id="pwindicator" class="pwindicator mt-2">
                            <div class="bar"></div>
                            <div class="label"></div>
                        </div>
                    </div>
                    <div class="form-group col-6">
                        <label>@lang('user.Select Role')</label>
                        <select class="form-control @error('role') is-invalid @enderror" multiple="" data-height="100%"
                            style="height: 100%;" name="role[]">
                            @foreach ($roles as $role)
                                <option value="{{ $role->name }}">
                                    {{ $role->name }}</option>
                            @endforeach
                        </select>
                        @error('role')
                            <span class="invalid-feedback" role="alert">
                                <strong>{{ $message }}</strong>
                            </span>
                        @enderror
                    </div>
                </div>

                <div class="card mt-5">
                    <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-3">
                        <h4 id="grab-me">@lang('user.Location (Optional)')</h4>
                        <div class="card-header-action">
                            <a data-collapse="#mycard-collapse-3" class="btn btn-icon btn-danger" href="#"><i
                                    class="fas fa-map-pin"></i></a>
                        </div>
                    </div>
                    <div class="collapse" id="mycard-collapse-3" style="">
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="country">@lang('user.Country')</label>
                                    <select class="form-control select2 @error('country') is-invalid @enderror"
                                        name="country" id="country" autofocus>
                                        <option value="" disabled selected>Choose...</option>
                                        @foreach ($countries as $country)
                                            <option value="{{ $country->id }}">
                                                {{ $country->name }}
                                            </option>
                                        @endforeach
                                    </select>
                                    @error('country')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="region">@lang('user.Region')</label>
                                    <select class="form-control select2 @error('region') is-invalid @enderror"
                                        name="region" id="region">
                                        <option value="" disabled selected>Choose Country To Continue</option>
                                    </select>
                                    @error('region')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label for="city">@lang('user.City')</label>
                                    <select class="form-control @error('city') is-invalid @enderror select2"
                                        name="city" id="city">
                                        <option value="" disabled selected>Choose Region To Continue</option>
                                    </select>
                                    @error('city')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                                <div class="form-group col-6">
                                    <label for="name">@lang('user.Building Number')</label>
                                    <input id="name" type="text" value="{{ old('building_number') }}"
                                        class="form-control @error('building_number') is-invalid @enderror"
                                        name="building_number" autofocus>
                                    @error('building_number')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <button type="submit" class="btn btn-danger btn-lg btn-block mt-4">
                        @lang('button.Create')
                    </button>
                </div>
            </form>
        </div>
    </div>


    <script>
        $(document).ready(function() {
            // Handle button click to generate password
            $('#generatePasswordBtn').on('click', function() {
                // Generate a random password
                var generatedPassword = generateRandomPassword(20); // You can specify the length

                // Display the generated password in the password field
                $('#password').val(generatedPassword);
            });

            // Handle button click to toggle password visibility
            $('#togglePasswordVisibility').on('click', function() {
                var passwordField = $('#password');
                var eyeIcon = $('#eyeIcon');

                // Toggle the input type between password and text
                var type = passwordField.attr('type') === 'password' ? 'text' : 'password';
                passwordField.attr('type', type);

                // Change the eye icon based on the input type
                eyeIcon.toggleClass('fa-eye-slash', type === 'text');
            });

            // Function to generate a random password
            function generateRandomPassword(length) {
                var charset =
                    "abcdefghijklmnopqrstuvwxyz!@#$%^&*_-=+-?\|/ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*_-=+-?\|/";
                var password = "";
                for (var i = 0; i < length; i++) {
                    var randomIndex = Math.floor(Math.random() * charset.length);
                    password += charset.charAt(randomIndex);
                }
                return password;
            }
        });
    </script>

    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Retrieve selected country code from local storage
            const selectedCountryCode = localStorage.getItem('selectedCountryCode');
            if (selectedCountryCode) {
                document.getElementById('countryCodeBtn').innerText = selectedCountryCode;
                document.getElementById('selectedCountryCode').value = selectedCountryCode;
            }

            // Event listener for dropdown items
            document.querySelectorAll('.dropdown-item').forEach(item => {
                item.addEventListener('click', event => {
                    const selectedCountryCode = event.target.getAttribute('data-code');
                    document.getElementById('countryCodeBtn').innerText = selectedCountryCode;
                    document.getElementById('selectedCountryCode').value = selectedCountryCode;
                    // Store selected country code in local storage
                    localStorage.setItem('selectedCountryCode', selectedCountryCode);
                });
            });
        });
    </script>

@endsection
