@extends('admin.layout.master')
@section('title', 'Profile')
@section('section', __('profile.Profile'))

@section('body')
    <section class="section">
        <div class="section-body">
            <h2 class="section-title">Hi, {{ Auth::user()->name }}!</h2>
            <p class="section-lead">
                @lang('profile.Change information about yourself on this page.')
            </p>

            <div class="col-12">
                <div class="card">
                    <form action="{{ route('profile.update', ['user' => Auth::user()->id]) }}" method="post">
                        @csrf
                        <div class="card-header">
                            <h4>@lang('profile.Edit Profile')</h4>
                            <div class="card-header-action">
                                <a class="btn btn-icon btn-danger" href="#"><i class="fas fa-user"></i></a>
                            </div>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-6">
                                    <label>@lang('profile.Name')</label>
                                    <input type="text" name="name"
                                        class="form-control @error('name') is-invalid @enderror"
                                        value="{{ Auth::user()->name }}">
                                    @error('name')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>

                                <div class="form-group col-6">
                                    <label>@lang('profile.Username')</label>
                                    <input type="text" name="username"
                                        class="form-control @error('username') is-invalid @enderror"
                                        value="{{ old('username', Auth::user()->username) }}" disabled>
                                    @error('username')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="row">
                                <div class="form-group col-6">
                                    <label>@lang('profile.Email')</label>
                                    <input type="email" name="email" class="form-control"
                                        value="{{ Auth::user()->email }}" disabled>
                                    <div class="invalid-feedback">
                                        Please fill in the email
                                    </div>
                                </div>
                                <div class="form-group col-6">
                                    <label>@lang('profile.Phone')</label>
                                    <input type="tel" name="phone"
                                        class="form-control @error('phone') is-invalid @enderror"
                                        value="{{ old('phone', Auth::user()->phone) }}">
                                    @error('phone')
                                        <span class="invalid-feedback" role="alert">
                                            <strong>{{ $message }}</strong>
                                        </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group">
                                <label>@lang('profile.Roles')</label>
                                <select class="form-control" multiple="" data-height="100%" style="height: 100%;"
                                    disabled>
                                    @foreach ($roles as $role)
                                        <option> {{ $role }} </option>
                                    @endforeach
                                </select>
                            </div>
                        </div>

                        <div class="card">
                            <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-3">
                                <h4 id="grab-me">@lang('profile.Location')</h4>
                                <div class="card-header-action">
                                    <a data-collapse="#mycard-collapse-3" class="btn btn-icon btn-danger" href="#"><i
                                            class="fas fa-map-pin"></i></a>
                                </div>
                            </div>
                            <div class="collapse show" id="mycard-collapse-3" style="">
                                <div class="card-body">
                                    <div class="row">
                                        <div class="form-group col-6">
                                            <label for="country">@lang('profile.Country')</label>
                                            <select class="form-control select2 @error('country') is-invalid @enderror"
                                                id="country" autofocus disabled>
                                                <option value="" disabled selected>{{ Auth::user()->country }}
                                                </option>
                                            </select>
                                            @error('country')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                        <div class="form-group col-6">
                                            <label for="region">@lang('profile.Region')</label>
                                            <select class="form-control select2 @error('region') is-invalid @enderror"
                                                id="region" disabled>
                                                <option value="" disabled selected>{{ Auth::user()->region }}
                                                </option>
                                            </select>
                                            @error('region')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>

                                    </div>
                                    <div class="row">
                                        <div class="form-group col-6">
                                            <label for="city">@lang('profile.City')</label>
                                            <select class="form-control @error('city') is-invalid @enderror select2"
                                                id="city" disabled>
                                                <option value="" disabled selected>{{ Auth::user()->city }}</option>
                                            </select>
                                            @error('city')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                        <div class="form-group col-6">
                                            <label for="name">@lang('profile.Building Number')</label>
                                            <input id="name" type="text"
                                                value="{{ Auth::user()->building_number }}"
                                                class="form-control @error('building_number') is-invalid @enderror"
                                                autofocus disabled>
                                            @error('building_number')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>


                        <div class="card">
                            <div class="card-header" data-toggle="collapse" data-target="#mycard-collapse-4">
                                <h4 id="grab-me">@lang('profile.Password Management')</h4>
                                <div class="card-header-action">
                                    <a data-collapse="#mycard-collapse-4" class="btn btn-icon btn-danger"
                                        href="#"><i class="fas fa-key"></i></a>
                                </div>
                            </div>
                            <div class="collapse show" id="mycard-collapse-4" style="">
                                <div class="card-body">
                                    <div class="row">
                                        <div class="form-group col-6">
                                            <label>@lang('profile.Current Password')</label>
                                            <input type="password" name="current_password"
                                                class="form-control @error('current_password') is-invalid @enderror">
                                            @error('current_password')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                        <div class="form-group col-6">
                                            <label>@lang('profile.New Password')</label>
                                            <input type="password" name="new_password"
                                                class="form-control @error('new_password') is-invalid @enderror">
                                            @error('new_password')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                            @enderror
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>


                        <div class="card-footer">
                            <button class="btn btn-danger" id="btn-mt">@lang('profile.Update Profile')</button>
                            <a class="btn btn-warning" id="btns"
                                href="{{ route('dashboard') }}">@lang('button.Back')</a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </section>


@endsection
