<?php

use App\Http\Controllers\ApiKeyController;
use App\Http\Controllers\AssetController;
use App\Http\Controllers\AssignAssetController;
use App\Http\Controllers\CityController;
use App\Http\Controllers\CountryController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\DepartmentController;
use App\Http\Controllers\EntityController;
use App\Http\Controllers\FinishAssetController;
use App\Http\Controllers\FlagAssetController;
use App\Http\Controllers\LanguageController;
use App\Http\Controllers\Level1Controller;
use App\Http\Controllers\Level2Controller;
use App\Http\Controllers\Level3Controller;
use App\Http\Controllers\Level4Controller;
use App\Http\Controllers\LevelController;
use App\Http\Controllers\MailController;
use App\Http\Controllers\MediaController;
use App\Http\Controllers\PermissionController;
use App\Http\Controllers\ProjectReportController;
use App\Http\Controllers\RegionController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\SettingController;
use App\Http\Controllers\StatusController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ValuationMethodController;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;


Route::prefix('admin')->middleware(['auth', 'set.locale'])->group(function () {

    Route::get('dashboard', [DashboardController::class, 'home'])->name('dashboard');

    // Users
    Route::get('users', [UserController::class, 'index'])->name('users');
    Route::get('users/create', [UserController::class, 'create'])->name('create.user');
    Route::post('users/store', [UserController::class, 'store'])->name('store.user');
    Route::get('users/{user}/edit', [UserController::class, 'edit'])->name('edit.user');
    Route::post('users/{user}/update', [UserController::class, 'update'])->name('update.user');
    Route::delete('users/{user}/delete', [UserController::class, 'delete'])->name('delete.user');
    Route::get('get-users', [UserController::class, 'getUsers'])->name('get_users');

    Route::get('user/{user}/profile', [UserController::class, 'profile'])->name('profile');
    Route::post('user/{user}/profile/update', [UserController::class, 'profileUpdate'])->name('profile.update');

    // Permissions
    Route::get('permission', [PermissionController::class, 'index'])->name('permissions');
    Route::get('permission/create', [PermissionController::class, 'create'])->name('create.permission');
    Route::post('permission/store', [PermissionController::class, 'store'])->name('store.permission');
    Route::get('permission/{permission}/edit', [PermissionController::class, 'edit'])->name('edit.permission');
    Route::post('permission/{permission}/update', [PermissionController::class, 'update'])->name('update.permission');
    Route::delete('permission/{permission}/delete', [PermissionController::class, 'delete'])->name('delete.permission');

    // Roles
    Route::get('role', [RoleController::class, 'index'])->name('roles');
    Route::get('role/create', [RoleController::class, 'create'])->name('create.role');
    Route::post('role/store', [RoleController::class, 'store'])->name('store.role');
    Route::get('role/{role}/edit', [RoleController::class, 'edit'])->name('edit.role');
    Route::post('role/{role}/update', [RoleController::class, 'update'])->name('update.role');
    Route::delete('role/{role}/delete', [RoleController::class, 'delete'])->name('delete.role');

    // Entities
    Route::get('entities', [EntityController::class, 'index'])->name('entities');
    Route::get('entities/create', [EntityController::class, 'create'])->name('create.entity');
    Route::post('entities/store', [EntityController::class, 'store'])->name('store.entity');
    Route::get('entities/{entity}/edit', [EntityController::class, 'edit'])->name('edit.entity');
    Route::post('entities/{entity}/update', [EntityController::class, 'update'])->name('update.entity');
    Route::delete('entities/{entity}/delete', [EntityController::class, 'delete'])->name('delete.entity');

    // Assets
    Route::get('assets', [AssetController::class, 'index'])->name('assets');
    Route::get('assets/create/{type}', [AssetController::class, 'create'])->name('create.asset');
    Route::post('assets/store', [AssetController::class, 'store'])->name('store.asset');
    Route::get('assets/{asset}/edit/{type}', [AssetController::class, 'edit'])->name('edit.asset');
    Route::post('assets/{asset}/update', [AssetController::class, 'update'])->name('update.asset');
    Route::get('assets/{asset}/view', [AssetController::class, 'show'])->name('show.asset');
    Route::delete('assets/{asset}/delete', [AssetController::class, 'delete'])->name('delete.asset');
    Route::get('assets/delete-all', [AssetController::class, 'deleteAll'])->name('asset.delete_all');
    Route::get('assets/bulk-edit', [AssetController::class, 'editAll'])->name('asset.edit_all');
    Route::post('assets/bulk-update', [AssetController::class, 'bulkUpdate'])->name('asset.bulk_update');
    Route::get('assets/bulk-download', [AssetController::class, 'assetsDocsDownload'])->name('asset.bulk_download');
    Route::get('assets/bulk-export-excel', [AssetController::class, 'bulkExport'])->name('bulk_export.asset');
    Route::get('assets/single-export-excel', [AssetController::class, 'singleExport'])->name('single_export.asset');
    Route::get('assets/export-excel', [AssetController::class, 'selectToExport'])->name('export.asset');
    Route::post('assets/export-excel', [AssetController::class, 'export'])->name('export.assets');
    Route::post('import-excel', [AssetController::class, 'importAssets'])->name('importAssets');
    Route::get('assets/assign', [AssetController::class, 'assign'])->name('assign.asset');
    Route::post('assets/assign-single-task', [AssetController::class, 'assignSingleTask'])->name('assign_single_task.asset');
    Route::get('assets/tasks', [AssetController::class, 'tasks'])->name('tasks.asset');
    Route::post('assets/assign-tasks', [AssetController::class, 'assignTasks'])->name('assign_tasks.asset');
    Route::get('assets/project-report', [ProjectReportController::class, 'projectReport'])->name('project_report.asset');
    Route::post('assets/export-project-report', [ProjectReportController::class, 'exportProjectReport'])->name('export_project_report.asset');
    Route::get('assets/flag', [FlagAssetController::class, 'index'])->name('flag.asset');
    Route::get('assets/flag/clear', [FlagAssetController::class, 'clear'])->name('clear.asset');
    Route::get('assets/flag/re-flag', [FlagAssetController::class, 'reFlag'])->name('re_flag.asset');

    Route::get('assets/image/download', [AssetController::class, 'downloadImage'])->name('download.image');
    Route::get('all-assets/image/download', [AssetController::class, 'downloadAllImage'])->name('download.all_image');

    Route::get('get-assets', [AssetController::class, 'getAssets'])->name('get.assets');
    Route::get('get-finish-assets', [FinishAssetController::class, 'getFinishAssets'])->name('get.finish_assets');
    Route::get('get-flag-assets', [FlagAssetController::class, 'getFlagAssets'])->name('get.flag_assets');

    Route::get('filter-assets', [AssetController::class, 'filterAssets'])->name('filter.assets');
    // Finish Asset
    Route::get('finish-assets', [FinishAssetController::class, 'index'])->name('finish.asset');

    Route::get('country-wise-assets', [AssetController::class, 'countryWiseAssets'])->name('country_wise.asset');
    Route::get('region-wise-assets', [AssetController::class, 'regionWiseAssets'])->name('region_wise.asset');

    // Status
    Route::get('status', [StatusController::class, 'index'])->name('status');
    Route::get('status/create', [StatusController::class, 'create'])->name('create.status');
    Route::post('status/store', [StatusController::class, 'store'])->name('store.status');
    Route::get('status/{status}/edit', [StatusController::class, 'edit'])->name('edit.status');
    Route::post('status/{status}/update', [StatusController::class, 'update'])->name('update.status');
    Route::delete('status/{status}/delete', [StatusController::class, 'delete'])->name('delete.status');

    // Assign Asset
    Route::get('assign-assets', [AssignAssetController::class, 'index'])->name('assign.asset_list');
    Route::get('get-assign-asset-list', [AssignAssetController::class, 'getAssignAssetList'])->name('get_assign_asset_list');

    Route::get('import', [AssetController::class, 'customImport'])->name('import.asset');

    Route::post('import/furniture', [AssetController::class, 'customImportAssetFurniture'])->name('importData.asset_furniture');
    Route::post('import/machinery', [AssetController::class, 'customImportAssetMachinery'])->name('importData.asset_machinary');

    Route::get('import/level', [AssetController::class, 'customImportLevel'])->name('import.assetLevel');
    Route::post('import/level', [AssetController::class, 'customImportAssetLevel'])->name('store.assetLevel');

    // Country
    Route::get('countries', [CountryController::class, 'index'])->name('countries');
    Route::get('country/create', [CountryController::class, 'create'])->name('create.country');
    Route::post('country/store', [CountryController::class, 'store'])->name('store.country');
    Route::get('country/{country}/edit', [CountryController::class, 'edit'])->name('edit.country');
    Route::post('country/{country}/update', [CountryController::class, 'update'])->name('update.country');
    Route::delete('country/{country}/delete', [CountryController::class, 'delete'])->name('delete.country');

    // Region
    Route::get('regions', [RegionController::class, 'index'])->name('regions');
    Route::get('region/create', [RegionController::class, 'create'])->name('create.region');
    Route::post('region/store', [RegionController::class, 'store'])->name('store.region');
    Route::get('region/{region}/edit', [RegionController::class, 'edit'])->name('edit.region');
    Route::post('region/{region}/update', [RegionController::class, 'update'])->name('update.region');
    Route::delete('region/{region}/delete', [RegionController::class, 'delete'])->name('delete.region');

    // City
    Route::get('cities', [CityController::class, 'index'])->name('cities');
    Route::get('city/create', [CityController::class, 'create'])->name('create.city');
    Route::post('city/store', [CityController::class, 'store'])->name('store.city');
    Route::get('city/{city}/edit', [CityController::class, 'edit'])->name('edit.city');
    Route::post('city/{city}/update', [CityController::class, 'update'])->name('update.city');
    Route::delete('city/{city}/delete', [CityController::class, 'delete'])->name('delete.city');

    // Valuation Method
    Route::get('valuations', [ValuationMethodController::class, 'index'])->name('valuations');
    Route::get('valuation/create', [ValuationMethodController::class, 'create'])->name('create.valuation');
    Route::post('valuation/store', [ValuationMethodController::class, 'store'])->name('store.valuation');
    Route::get('valuation/{valuation}/edit', [ValuationMethodController::class, 'edit'])->name('edit.valuation');
    Route::post('valuation/{valuation}/update', [ValuationMethodController::class, 'update'])->name('update.valuation');
    Route::delete('valuation/{valuation}/delete', [ValuationMethodController::class, 'delete'])->name('delete.valuation');

    // Level 1
    Route::get('level1', [Level1Controller::class, 'index'])->name('level1');
    Route::get('level1/create', [Level1Controller::class, 'create'])->name('create.level1');
    Route::post('level1/store', [Level1Controller::class, 'store'])->name('store.level1');
    Route::get('level1/{level1}/edit', [Level1Controller::class, 'edit'])->name('edit.level1');
    Route::post('level1/{level1}/update', [Level1Controller::class, 'update'])->name('update.level1');
    Route::delete('level1/{level1}/delete', [Level1Controller::class, 'delete'])->name('delete.level1');

    // Level 2
    Route::get('level2', [Level2Controller::class, 'index'])->name('level2');
    Route::get('level2/create', [Level2Controller::class, 'create'])->name('create.level2');
    Route::post('level2/store', [Level2Controller::class, 'store'])->name('store.level2');
    Route::get('level2/{level2}/edit', [Level2Controller::class, 'edit'])->name('edit.level2');
    Route::post('level2/{level2}/update', [Level2Controller::class, 'update'])->name('update.level2');
    Route::delete('level2/{level2}/delete', [Level2Controller::class, 'delete'])->name('delete.level2');

    // Level 3
    Route::get('level3', [Level3Controller::class, 'index'])->name('level3');
    Route::get('level3/create', [Level3Controller::class, 'create'])->name('create.level3');
    Route::post('level3/store', [Level3Controller::class, 'store'])->name('store.level3');
    Route::get('level3/{level3}/edit', [Level3Controller::class, 'edit'])->name('edit.level3');
    Route::post('level3/{level3}/update', [Level3Controller::class, 'update'])->name('update.level3');
    Route::delete('level3/{level3}/delete', [Level3Controller::class, 'delete'])->name('delete.level3');

    // Level 4
    Route::get('level4', [Level4Controller::class, 'index'])->name('level4');
    Route::get('level4/create', [Level4Controller::class, 'create'])->name('create.level4');
    Route::post('level4/store', [Level4Controller::class, 'store'])->name('store.level4');
    Route::get('level4/{level4}/edit', [Level4Controller::class, 'edit'])->name('edit.level4');
    Route::post('level4/{level4}/update', [Level4Controller::class, 'update'])->name('update.level4');
    Route::delete('level4/{level4}/delete', [Level4Controller::class, 'delete'])->name('delete.level4');

    // Settings
    Route::get('settings', [SettingController::class, 'cacheSettings'])->name('cache_setting');
    Route::get('clear-cache', [SettingController::class, 'cacheClear'])->name('cache_clear');
    Route::get('view-cache', [SettingController::class, 'viewClear'])->name('view_clear');
    Route::get('department-session-clear', [SettingController::class, 'departmentSessionClear'])->name('department_session_clear');

    Route::post('check-location', [AssetController::class, 'checkLocation'])->name('check_location.match');

    // Department
    Route::get('departments', [DepartmentController::class, 'index'])->name('departments');
    Route::get('department/create', [DepartmentController::class, 'create'])->name('create.department');
    Route::post('department/store', [DepartmentController::class, 'store'])->name('store.department');
    Route::get('department/{department}/edit', [DepartmentController::class, 'edit'])->name('edit.department');
    Route::post('department/{department}/update', [DepartmentController::class, 'update'])->name('update.department');
    Route::delete('department/{department}/delete', [DepartmentController::class, 'delete'])->name('delete.department');

    // AJAx
    Route::get('fetch-regions/{countryId}', [AssetController::class, 'fetchRegions']);
    Route::get('fetch-cities/{regionId}', [AssetController::class, 'fetchCities']);

    Route::get('get-level1-data/{level2}', [LevelController::class, 'getLevel1Data']);
    Route::get('get-level2-level1-data/{level3Value}', [LevelController::class, 'getLevel2Level1Data']);

    Route::get('media', [MediaController::class, 'media'])->name('media');
    Route::get('set-language/{lang}', [LanguageController::class, 'setLanguage'])->name('set.language');
});





Route::get('/', function () {
    return redirect()->route('dashboard');
});

Route::get('home', function () {
    return redirect()->route('dashboard');
});


// Auth::routes();
Auth::routes(['register' => false]);

Route::get('/clear', function () {

    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('config:cache');
    Artisan::call('view:clear');

    return "Cleared!";
});
